#!/usr/bin/perl

use strict;
use lib 't/lib';

use Test::Deep qw(cmp_deeply);

use FusionInventory::Agent::Tools::Hardware;
use FusionInventory::Test::Hardware;

my %tests = (
    'cisco/C1040.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1040 Software (C1140-K9W7-M), Version 12.4(25d)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 11-Aug-11 02:58 by prod_rel_team',
            SNMPHOSTNAME => 'WIFI-IPJ-etage2-82.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1040 Software (C1140-K9W7-M), Version 12.4(25d)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 11-Aug-11 02:58 by prod_rel_team',
            SNMPHOSTNAME => 'WIFI-IPJ-etage2-82.wifi-mngt.dauphine.fr',
            MAC          => 'A4:18:75:C2:67:00',
            MODELSNMP    => 'Networking2178',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCZ1623Z2XQ',
        },
        {
            PORTS => {
                PORT => [
                    {
                        IFNUMBER         => '1',
                        IFNAME           => 'Do0',
                        IFOUTERRORS      => '7309',
                        IFINERRORS       => '0',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)',
                        MAC              => 'A4:18:75:C2:67:00',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFINOCTETS       => '2545707486',
                        IFSPEED          => '54000000',
                        IFOUTOCTETS      => '2562804791',
                        IFDESCR          => 'Dot11Radio0',
                        IFMTU            => '1500',
                        IFTYPE           => 'ieee80211(71)'
                    },
                    {
                        IFLASTCHANGE     => '(1620) 0:00:16.20',
                        IFINOCTETS       => '0',
                        MAC              => 'A4:18:75:A5:27:00',
                        IFTYPE           => 'ieee80211(71)',
                        IFMTU            => '1500',
                        IFOUTOCTETS      => '0',
                        IFDESCR          => 'Dot11Radio1',
                        IFSPEED          => '54000000',
                        IFNAME           => 'Do1',
                        IFOUTERRORS      => '0',
                        IFNUMBER         => '2',
                        IFSTATUS         => 'down(2)',
                        IFINTERNALSTATUS => 'down(2)',
                        IFINERRORS       => '0'
                    },
                    {
                        IFSPEED          => '1000000000',
                        IFDESCR          => 'GigabitEthernet0',
                        IFOUTOCTETS      => '2425186262',
                        IFMTU            => '1500',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'A4:93:4C:93:A1:B5',
                        IFINOCTETS       => '1203274941',
                        IFLASTCHANGE     => '(1559) 0:00:15.59',
                        IFSTATUS         => 'up(1)',
                        IFINERRORS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFNUMBER         => '3',
                        IFNAME           => 'Gi0',
                        IFOUTERRORS      => '0'
                    },
                    {
                        IFOUTERRORS      => '0',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '4',
                        IFINERRORS       => '0',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFINOCTETS       => '0',
                        IFTYPE           => 'other(1)',
                        IFMTU            => '1500',
                        IFOUTOCTETS      => '0',
                        IFDESCR          => 'Null0',
                        IFSPEED          => '4294967295'
                    },
                    {
                        IFTYPE           => 'l2vlan(135)',
                        IFMTU            => '1500',
                        IFDESCR          => 'Dot11Radio0.7',
                        IFOUTOCTETS      => '3114577963',
                        IFSPEED          => '54000000',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFINOCTETS       => '1696380185',
                        MAC              => 'A4:18:75:C2:67:00',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)',
                        IFNAME           => 'Do0.7',
                        IFNUMBER         => '5'
                    },
                    {
                        IFINTERNALSTATUS => 'up(1)',
                        IFSTATUS         => 'up(1)',
                        IFNAME           => 'Do0.18',
                        IFNUMBER         => '6',
                        IFTYPE           => 'l2vlan(135)',
                        IFMTU            => '1500',
                        IFDESCR          => 'Dot11Radio0.18',
                        IFOUTOCTETS      => '2680413485',
                        IFSPEED          => '54000000',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFINOCTETS       => '154557539',
                        MAC              => 'A4:18:75:C2:67:00'
                    },
                    {
                        MAC              => 'A4:18:75:C2:67:00',
                        IFINOCTETS       => '116190244',
                        IFLASTCHANGE     => '(767607999) 88 days, 20:14:39.99',
                        IFSPEED          => '54000000',
                        IFDESCR          => 'Dot11Radio0.40',
                        IFOUTOCTETS      => '2076205012',
                        IFMTU            => '1500',
                        IFTYPE           => 'l2vlan(135)',
                        IFNUMBER         => '7',
                        IFNAME           => 'Do0.40',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)'
                    },
                    {
                        IFNUMBER         => '8',
                        IFNAME           => 'Gi0.7',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)',
                        MAC              => 'A4:93:4C:93:A1:B5',
                        IFINOCTETS       => '1679633303',
                        IFLASTCHANGE     => '(1527) 0:00:15.27',
                        IFSPEED          => '1000000000',
                        IFDESCR          => 'GigabitEthernet0.7',
                        IFOUTOCTETS      => '1704767676',
                        IFMTU            => '1500',
                        IFTYPE           => 'l2vlan(135)'
                    },
                    {
                        IFNAME           => 'Gi0.18',
                        IFNUMBER         => '9',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1531) 0:00:15.31',
                        IFINOCTETS       => '2795453458',
                        MAC              => 'A4:93:4C:93:A1:B5',
                        IFTYPE           => 'l2vlan(135)',
                        IFMTU            => '1500',
                        IFOUTOCTETS      => '154132236',
                        IFDESCR          => 'GigabitEthernet0.18',
                        IFSPEED          => '1000000000'
                    },
                    {
                        IFOUTOCTETS      => '111865705',
                        IFDESCR          => 'GigabitEthernet0.40',
                        IFSPEED          => '1000000000',
                        IFTYPE           => 'l2vlan(135)',
                        IFMTU            => '1500',
                        IFINOCTETS       => '2883284913',
                        IFLASTCHANGE     => '(1531) 0:00:15.31',
                        MAC              => 'A4:93:4C:93:A1:B5',
                        IFINTERNALSTATUS => 'up(1)',
                        IFSTATUS         => 'up(1)',
                        IFNUMBER         => '10',
                        IFNAME           => 'Gi0.40'
                    },
                    {
                        IFMTU            => '1500',
                        IFTYPE           => 'bridge(209)',
                        IFSPEED          => '54000000',
                        IFOUTOCTETS      => '419789539',
                        IFDESCR          => 'BVI1',
                        MAC              => 'A4:93:4C:93:A1:B5',
                        IFLASTCHANGE     => '(1634) 0:00:16.34',
                        IFINOCTETS       => '607347610',
                        IFSTATUS         => 'up(1)',
                        IFINTERNALSTATUS => 'up(1)',
                        IFINERRORS       => '0',
                        IFNAME           => 'BV1',
                        IFOUTERRORS      => '0',
                        IFNUMBER         => '11'
                    }
                ]
            },
            INFO => {
                MANUFACTURER => 'Cisco',
                UPTIME       => '(829014147) 95 days, 22:49:01.47',
                MODEL        => 'AIR-AP1042N-E-K9  ',
                MAC          => 'A4:18:75:C2:67:00',
                SERIAL       => 'FCZ1623Z2XQ',
                IPS          => {
                    IP => [ '192.168.55.82' ]
                },
                RAM      => 95,
                TYPE     => 'NETWORKING',
                ID       => undef,
                CPU      => '96',
                FIRMWARE => 'CW_VERSION$12.4(25d)JA1$',
                COMMENTS => 'Cisco IOS Software, C1040 Software (C1140-K9W7-M), Version 12.4(25d)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 11-Aug-11 02:58 by prod_rel_team',
                NAME => 'WIFI-IPJ-etage2-82.wifi-mngt.dauphine.fr'
            }
        }
    ],
    'cisco/C1130.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            MAC          => '00:00:00:00:00:00',
            SNMPHOSTNAME => 'ap-CP6-BU-161.wifi-mngt.dauphine.fr'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            MAC          => '00:13:5F:FA:F2:50',
            SNMPHOSTNAME => 'ap-CP6-BU-161.wifi-mngt.dauphine.fr',
            MODELSNMP    => 'Networking2176',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q00Z',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
                CPU          => '97',
                FIRMWARE     => 'CW_VERSION$12.4(10b)JA3$',
                ID           => undef,
                MAC          => '00:13:5F:FA:F2:50',
                MANUFACTURER => 'Cisco',
                MODEL        => 'AIR-AP1131AG-E-K9 ',
                NAME         => 'ap-CP6-BU-161.wifi-mngt.dauphine.fr',
                RAM          => 23,
                SERIAL       => 'FCZ0930Q00Z',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Dot11Radio0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2723745631',
                        IFLASTCHANGE => '(7701) 0:01:17.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '91561',
                        IFOUTOCTETS  => '2002017105',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'ieee80211(71)',
                        MAC          => '00:13:5F:FA:F2:50'
                    },
                    {
                        IFDESCR      => 'Dot11Radio1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(1204) 0:00:12.04',
                        IFMTU        => '1500',
                        IFNUMBER     => '2',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'ieee80211(71)',
                        MAC          => '00:13:5F:FE:F2:30'
                    },
                    {
                        IFDESCR      => 'FastEthernet0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1922539881',
                        IFLASTCHANGE => '(1142) 0:00:11.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '3',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3697487330',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:14:6A:D6:B1:CE'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '4',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    },
                    {
                        IFDESCR      => 'Dot11Radio0.7',
                        IFINOCTETS   => '2687372679',
                        IFLASTCHANGE => '(7607) 0:01:16.07',
                        IFMTU        => '1500',
                        IFNUMBER     => '5',
                        IFOUTOCTETS  => '1195595259',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:13:5F:FA:F2:50'
                    },
                    {
                        IFDESCR      => 'Dot11Radio0.18',
                        IFINOCTETS   => '23434868',
                        IFLASTCHANGE => '(7607) 0:01:16.07',
                        IFMTU        => '1500',
                        IFNUMBER     => '6',
                        IFOUTOCTETS  => '822989071',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:13:5F:FA:F2:50'
                    },
                    {
                        IFDESCR      => 'Dot11Radio0.40',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(7607) 0:01:16.07',
                        IFMTU        => '1500',
                        IFNUMBER     => '7',
                        IFOUTOCTETS  => '540',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:13:5F:FA:F2:50'
                    },
                    {
                        IFDESCR      => 'Dot11Radio1.40',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(1096) 0:00:10.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '8',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:13:5F:FE:F2:30'
                    },
                    {
                        IFDESCR      => 'FastEthernet0.7',
                        IFINOCTETS   => '3495668832',
                        IFLASTCHANGE => '(1107) 0:00:11.07',
                        IFMTU        => '1500',
                        IFNUMBER     => '9',
                        IFOUTOCTETS  => '2702597576',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:14:6A:D6:B1:CE'
                    },
                    {
                        IFDESCR      => 'FastEthernet0.18',
                        IFINOCTETS   => '843457950',
                        IFLASTCHANGE => '(1108) 0:00:11.08',
                        IFMTU        => '1500',
                        IFNUMBER     => '10',
                        IFOUTOCTETS  => '23050498',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:14:6A:D6:B1:CE'
                    },
                    {
                        IFDESCR      => 'FastEthernet0.40',
                        IFINOCTETS   => '1016603638',
                        IFLASTCHANGE => '(1109) 0:00:11.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '11',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'l2vlan(135)',
                        MAC          => '00:14:6A:D6:B1:CE'
                    },
                    {
                        IFDESCR      => 'BVI1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '410354460',
                        IFLASTCHANGE => '(1210) 0:00:12.10',
                        IFMTU        => '1500',
                        IFNUMBER     => '12',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '10537521',
                        IFSPEED      => '54000000',
                        IFTYPE       => 'bridge(209)',
                        MAC          => '00:14:6A:D6:B1:CE'
                    }
                ]
            }
        }
    ],
    'cisco/C1130.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            SNMPHOSTNAME => 'ap-P405-45.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
            SNMPHOSTNAME => 'ap-P405-45.wifi-mngt.dauphine.fr',
            MAC          => '00:13:5F:FA:FA:50',
            MODELSNMP    => 'Networking2176',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q01A',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(10b)JA3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2008 by Cisco Systems, Inc.
Compiled Wed 19-Mar-08 18:08 by prod_rel_team',
                CPU      => '98',
                FIRMWARE => 'CW_VERSION$12.4(10b)JA3$',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.55.45' ]
                },
                MAC          => '00:13:5F:FA:FA:50',
                MANUFACTURER => 'Cisco',
                MODEL        => 'AIR-AP1131AG-E-K9 ',
                NAME         => 'ap-P405-45.wifi-mngt.dauphine.fr',
                RAM          => 23,
                SERIAL       => 'FCZ0930Q01A',
                TYPE         => 'NETWORKING',
                UPTIME       => '(34865419) 4 days, 0:50:54.19'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Dot11Radio0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1847463852',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(7532) 0:01:15.32',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '86765',
                        IFOUTOCTETS      => '782166020',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ieee80211(71)',
                        MAC              => '00:13:5F:FA:FA:50'
                    },
                    {
                        IFDESCR          => 'Dot11Radio1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(1198) 0:00:11.98',
                        IFMTU            => '1500',
                        IFNAME           => 'Do1',
                        IFNUMBER         => '2',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ieee80211(71)',
                        MAC              => '00:13:5F:FE:FA:30'
                    },
                    {
                        IFDESCR          => 'FastEthernet0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '3855516427',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1136) 0:00:11.36',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0',
                        IFNUMBER         => '3',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2786837221',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:14:6A:D6:B2:CE'
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '4',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.7',
                        IFINOCTETS       => '1833237924',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(7438) 0:01:14.38',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.7',
                        IFNUMBER         => '5',
                        IFOUTOCTETS      => '3508924423',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:FA:50'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.18',
                        IFINOCTETS       => '396827',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(7438) 0:01:14.38',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.18',
                        IFNUMBER         => '6',
                        IFOUTOCTETS      => '694399025',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:FA:50'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.40',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(7438) 0:01:14.38',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.40',
                        IFNUMBER         => '7',
                        IFOUTOCTETS      => '6940608',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:FA:50'
                    },
                    {
                        IFDESCR          => 'Dot11Radio1.40',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(1089) 0:00:10.89',
                        IFMTU            => '1500',
                        IFNAME           => 'Do1.40',
                        IFNUMBER         => '8',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FE:FA:30'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.7',
                        IFINOCTETS       => '1143594822',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1100) 0:00:11.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.7',
                        IFNUMBER         => '9',
                        IFOUTOCTETS      => '1841662240',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:CE'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.18',
                        IFINOCTETS       => '714789539',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1102) 0:00:11.02',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.18',
                        IFNUMBER         => '10',
                        IFOUTOCTETS      => '306665',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:CE'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.40',
                        IFINOCTETS       => '970211324',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1103) 0:00:11.03',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.40',
                        IFNUMBER         => '11',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:CE'
                    },
                    {
                        IFDESCR          => 'BVI1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '411852720',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1204) 0:00:12.04',
                        IFMTU            => '1500',
                        IFNAME           => 'BV1',
                        IFNUMBER         => '12',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '8408247',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'bridge(209)',
                        MAC              => '00:14:6A:D6:B2:CE'
                    }
                ]
            }
        }
    ],
    'cisco/C1130.3.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            MAC          => '00:00:00:00:00:00',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            MAC          => '00:13:5F:FA:F9:A0',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MODELSNMP    => 'Networking2191',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q01N',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
                CPU      => '97',
                FIRMWARE => 'CW_VERSION$12.4(21a)JA1$',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.55.141' ]
                },
                MAC          => '00:13:5F:FA:F9:A0',
                MANUFACTURER => 'Cisco',
                MODEL        => 'AIR-AP1131AG-E-K9 ',
                NAME         => 'ap-D416-141.wifi-mngt.dauphine.fr',
                RAM          => 23,
                SERIAL       => 'FCZ0930Q01N',
                TYPE         => 'NETWORKING',
                UPTIME       => '(131654419) 15 days, 5:42:24.19'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Dot11Radio0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1986250540',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '15496',
                        IFOUTOCTETS      => '4034040569',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ieee80211(71)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(1388) 0:00:13.88',
                        IFMTU            => '1500',
                        IFNAME           => 'Do1',
                        IFNUMBER         => '2',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ieee80211(71)',
                        MAC              => '00:13:5F:FE:F9:80'
                    },
                    {
                        IFDESCR          => 'FastEthernet0',
                        IFINERRORS       => '1817884',
                        IFINOCTETS       => '3182552204',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1333) 0:00:13.33',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0',
                        IFNUMBER         => '3',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2589712033',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '4',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.7',
                        IFINOCTETS       => '1525293600',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.7',
                        IFNUMBER         => '5',
                        IFOUTOCTETS      => '902858571',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.18',
                        IFINOCTETS       => '8650226',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.18',
                        IFNUMBER         => '6',
                        IFOUTOCTETS      => '827133541',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.40',
                        IFINOCTETS       => '46832680',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.40',
                        IFNUMBER         => '7',
                        IFOUTOCTETS      => '39829396',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio1.40',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(1288) 0:00:12.88',
                        IFMTU            => '1500',
                        IFNAME           => 'Do1.40',
                        IFNUMBER         => '8',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FE:F9:80'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.7',
                        IFINOCTETS       => '3827474904',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1298) 0:00:12.98',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.7',
                        IFNUMBER         => '9',
                        IFOUTOCTETS      => '1534007354',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.18',
                        IFINOCTETS       => '871447532',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1299) 0:00:12.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.18',
                        IFNUMBER         => '10',
                        IFOUTOCTETS      => '8082038',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.40',
                        IFINOCTETS       => '1834903826',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1300) 0:00:13.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.40',
                        IFNUMBER         => '11',
                        IFOUTOCTETS      => '46294714',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'BVI1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '476038021',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1402) 0:00:14.02',
                        IFMTU            => '1500',
                        IFNAME           => 'BV1',
                        IFNUMBER         => '12',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '22916493',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'bridge(209)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    }
                ]
            }
        }
    ],
    'cisco/C1130.4.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MAC          => '00:00:00:00:00:00'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
            SNMPHOSTNAME => 'ap-D416-141.wifi-mngt.dauphine.fr',
            MAC          => '00:13:5F:FA:F9:A0',
            MODELSNMP    => 'Networking2191',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCZ0930Q01N',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C1130 Software (C1130-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Wed 16-Sep-09 18:36 by prod_rel_team',
                CPU      => '98',
                FIRMWARE => 'CW_VERSION$12.4(21a)JA1$',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.55.141' ]
                },
                MAC          => '00:13:5F:FA:F9:A0',
                MANUFACTURER => 'Cisco',
                MODEL        => 'AIR-AP1131AG-E-K9 ',
                NAME         => 'ap-D416-141.wifi-mngt.dauphine.fr',
                RAM          => 23,
                SERIAL       => 'FCZ0930Q01N',
                TYPE         => 'NETWORKING',
                UPTIME       => '(131936738) 15 days, 6:29:27.38'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Dot11Radio0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2008650512',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '15567',
                        IFOUTOCTETS      => '4262978259',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ieee80211(71)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(1388) 0:00:13.88',
                        IFMTU            => '1500',
                        IFNAME           => 'Do1',
                        IFNUMBER         => '2',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ieee80211(71)',
                        MAC              => '00:13:5F:FE:F9:80'
                    },
                    {
                        IFDESCR          => 'FastEthernet0',
                        IFINERRORS       => '1817884',
                        IFINOCTETS       => '3482914011',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1333) 0:00:13.33',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0',
                        IFNUMBER         => '3',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2611425256',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '4',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.7',
                        IFINOCTETS       => '1545983180',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.7',
                        IFNUMBER         => '5',
                        IFOUTOCTETS      => '1194767553',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.18',
                        IFINOCTETS       => '8650226',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.18',
                        IFNUMBER         => '6',
                        IFOUTOCTETS      => '828451237',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio0.40',
                        IFINOCTETS       => '46832680',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79949565) 9 days, 6:04:55.65',
                        IFMTU            => '1500',
                        IFNAME           => 'Do0.40',
                        IFNUMBER         => '7',
                        IFOUTOCTETS      => '39829396',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FA:F9:A0'
                    },
                    {
                        IFDESCR          => 'Dot11Radio1.40',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(1288) 0:00:12.88',
                        IFMTU            => '1500',
                        IFNAME           => 'Do1.40',
                        IFNUMBER         => '8',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:13:5F:FE:F9:80'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.7',
                        IFINOCTETS       => '4128177048',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1298) 0:00:12.98',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.7',
                        IFNUMBER         => '9',
                        IFOUTOCTETS      => '1554773976',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.18',
                        IFINOCTETS       => '872932219',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1299) 0:00:12.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.18',
                        IFNUMBER         => '10',
                        IFOUTOCTETS      => '8082038',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'FastEthernet0.40',
                        IFINOCTETS       => '1835337081',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1300) 0:00:13.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0.40',
                        IFNUMBER         => '11',
                        IFOUTOCTETS      => '46294714',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'l2vlan(135)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    },
                    {
                        IFDESCR          => 'BVI1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '476739635',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1402) 0:00:14.02',
                        IFMTU            => '1500',
                        IFNAME           => 'BV1',
                        IFNUMBER         => '12',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '23738876',
                        IFSPEED          => '54000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'bridge(209)',
                        MAC              => '00:14:6A:D6:B2:B8'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            MAC          => '00:24:13:EA:A7:00',
            SNMPHOSTNAME => 'CB-27.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            MAC          => '00:24:13:EA:A7:00',
            SNMPHOSTNAME => 'CB-27.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2177',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1247X5DX',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.27' ]
                },
                MAC          => '00:24:13:EA:A7:00',
                MANUFACTURER => 'Cisco',
                MODEL        => 'WS-C2960-24TC-L',
                NAME         => 'CB-27.mgmt.dauphine.fr',
                SERIAL       => 'FOC1247X5DX',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1955878377',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4607) 0:00:46.07',
                        IFMTU            => '1500',
                        IFNAME           => 'Vl1',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2756311186',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)',
                        MAC              => '00:24:13:EA:A7:40'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '3059673658',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(35962354) 4 days, 3:53:43.54',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/1',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2957789612',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:01'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/2',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:02'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '41',
                        IFINOCTETS       => '106446611',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(45145198) 5 days, 5:24:11.98',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/3',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '6780515',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:03'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/4',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:04'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '55117404',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(3688819692) 426 days, 22:43:16.92',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/5',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1951371841',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:05'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/6',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:06'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '779472584',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(45289939) 5 days, 5:48:19.39',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/7',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '137886525',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:07'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/8',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:08'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/9',
                        IFINERRORS       => '86328',
                        IFINOCTETS       => '3564203230',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(449117911) 51 days, 23:32:59.11',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/9',
                        IFNUMBER         => '10009',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2567343375',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:09'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/10',
                        IFNUMBER         => '10010',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:0A'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/11',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '4193136023',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4259630157) 493 days, 0:18:21.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/11',
                        IFNUMBER         => '10011',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '274037618',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:0B'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/12',
                        IFNUMBER         => '10012',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:0C'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/13',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2204612361',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(711110280) 82 days, 7:18:22.80',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/13',
                        IFNUMBER         => '10013',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1967389962',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:0D'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4156) 0:00:41.56',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/14',
                        IFNUMBER         => '10014',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:0E'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '3669484140',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(3688824604) 426 days, 22:44:06.04',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/15',
                        IFNUMBER         => '10015',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3228371931',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:0F'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/16',
                        IFNUMBER         => '10016',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:10'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/17',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '1619195842',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(3688836292) 426 days, 22:46:02.92',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/17',
                        IFNUMBER         => '10017',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1395113604',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:11'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/18',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/18',
                        IFNUMBER         => '10018',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:12'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/19',
                        IFNUMBER         => '10019',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:13'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/20',
                        IFNUMBER         => '10020',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:14'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/21',
                        IFNUMBER         => '10021',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:15'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/22',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/22',
                        IFNUMBER         => '10022',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:16'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/23',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4157) 0:00:41.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/23',
                        IFNUMBER         => '10023',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:17'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/24',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '62439235',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(180206948) 20 days, 20:34:29.48',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/24',
                        IFNUMBER         => '10024',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '929961356',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:18'
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1780492746',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(310281198) 35 days, 21:53:31.98',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi0/1',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3781185060',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:19'
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1622468503',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4259602380) 493 days, 0:13:43.80',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi0/2',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2698146544',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '00:24:13:EA:A7:1A'
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            MAC          => '00:24:13:CE:D7:00',
            SNMPHOSTNAME => 'AP-P101-59.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            MAC          => '00:24:13:CE:D7:00',
            SNMPHOSTNAME => 'AP-P101-59.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2177',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1247X5D4',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
                ID           => undef,
                MAC          => '00:24:13:CE:D7:00',
                MANUFACTURER => 'Cisco',
                MODEL        => 'WS-C2960-24TC-L',
                NAME         => 'AP-P101-59.mgmt.dauphine.fr',
                SERIAL       => 'FOC1247X5D4',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1969699486',
                        IFLASTCHANGE => '(448584218) 51 days, 22:04:02.18',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1143740170',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:24:13:CE:D7:40'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '160360322',
                        IFLASTCHANGE => '(1666698681) 192 days, 21:43:06.81',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2520427958',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:01'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '1354978920',
                        IFLASTCHANGE => '(1288669773) 149 days, 3:38:17.73',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1444296343',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:02'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1418474807',
                        IFLASTCHANGE => '(1667811201) 193 days, 0:48:32.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3697736928',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:03'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '972898572',
                        IFLASTCHANGE => '(361575212) 41 days, 20:22:32.12',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2874278107',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:04'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '842225921',
                        IFLASTCHANGE => '(361564184) 41 days, 20:20:41.84',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2097721511',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:05'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '612658',
                        IFLASTCHANGE => '(1460643496) 169 days, 1:20:34.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '7517632',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:06'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '860540279',
                        IFLASTCHANGE => '(1545691195) 178 days, 21:35:11.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '356275802',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:07'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '59734207',
                        IFLASTCHANGE => '(1669007485) 193 days, 4:07:54.85',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1849411001',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:08'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2469094479',
                        IFLASTCHANGE => '(1599428965) 185 days, 2:51:29.65',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '5',
                        IFOUTOCTETS  => '4060044107',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:09'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '102950896',
                        IFLASTCHANGE => '(1399544874) 161 days, 23:37:28.74',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '650135037',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:0A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4167) 0:00:41.67',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:0B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '43235636',
                        IFLASTCHANGE => '(1666029375) 192 days, 19:51:33.75',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '680136759',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:0C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '239329601',
                        IFLASTCHANGE => '(1286978674) 148 days, 22:56:26.74',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '828899275',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:0D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '16887',
                        IFINOCTETS   => '330810944',
                        IFLASTCHANGE => '(1668531324) 193 days, 2:48:33.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1855427971',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:0E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '107079056',
                        IFLASTCHANGE => '(1667075555) 192 days, 22:45:55.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1133282038',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:0F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '75627900',
                        IFLASTCHANGE => '(1332165044) 154 days, 4:27:30.44',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '857357031',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:10'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '1569285360',
                        IFLASTCHANGE => '(1399546606) 161 days, 23:37:46.06',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '209932792',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:11'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '62683816',
                        IFLASTCHANGE => '(1659597753) 192 days, 1:59:37.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1032329852',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:12'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '252',
                        IFINOCTETS   => '148292480',
                        IFLASTCHANGE => '(1660563317) 192 days, 4:40:33.17',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1865203761',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:13'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1414423',
                        IFLASTCHANGE => '(1286973610) 148 days, 22:55:36.10',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '37991943',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:14'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '470135831',
                        IFLASTCHANGE => '(1666644488) 192 days, 21:34:04.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2845209002',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:15'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '383001306',
                        IFLASTCHANGE => '(1539355445) 178 days, 3:59:14.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2428516158',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:16'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4168) 0:00:41.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:17'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4168) 0:00:41.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:18',
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4168) 0:00:41.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:19'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '3449371397',
                        IFLASTCHANGE => '(448584503) 51 days, 22:04:05.03',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2995445287',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:24:13:CE:D7:1A'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.3.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            MAC          => '00:1B:54:D6:39:00',
            SNMPHOSTNAME => 'CP-P101-37.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
            MAC          => '00:1B:54:D6:39:00',
            SNMPHOSTNAME => 'CP-P101-37.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2177',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1113X1PE',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 02:53 by prod_rel_team',
                ID           => undef,
                MAC          => '00:1B:54:D6:39:00',
                MANUFACTURER => 'Cisco',
                MODEL        => 'WS-C2960-24TC-L',
                NAME         => 'CP-P101-37.mgmt.dauphine.fr',
                SERIAL       => 'FOC1113X1PE',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2030921664',
                        IFLASTCHANGE => '(4584) 0:00:45.84',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '951088659',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:1B:54:D6:39:40'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '369925658',
                        IFLASTCHANGE => '(1657748225) 191 days, 20:51:22.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '926844080',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:01'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4140) 0:00:41.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:02'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '393092436',
                        IFLASTCHANGE => '(1641428469) 189 days, 23:31:24.69',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3227489290',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:03'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4140) 0:00:41.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:04'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '521485508',
                        IFLASTCHANGE => '(1668711130) 193 days, 3:18:31.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '73',
                        IFOUTOCTETS  => '2052899224',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:05'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4140) 0:00:41.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:06'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '34',
                        IFINOCTETS   => '152710057',
                        IFLASTCHANGE => '(1149060288) 132 days, 23:50:02.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '297',
                        IFOUTOCTETS  => '2698203912',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:07'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '188163118',
                        IFLASTCHANGE => '(1608943026) 186 days, 5:17:10.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1553262039',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:08'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '2609670352',
                        IFLASTCHANGE => '(1669071909) 193 days, 4:18:39.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3992264533',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:09'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '49267770',
                        IFLASTCHANGE => '(1651098591) 191 days, 2:23:05.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '654794463',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:0A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '257576986',
                        IFLASTCHANGE => '(1512173256) 175 days, 0:28:52.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4219065024',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:0B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '613',
                        IFINOCTETS   => '36205380',
                        IFLASTCHANGE => '(1512143171) 175 days, 0:23:51.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '347903192',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:0C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '208833434',
                        IFLASTCHANGE => '(1634598779) 189 days, 4:33:07.79',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '191680982',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:0D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4141) 0:00:41.41',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:0E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '212801623',
                        IFLASTCHANGE => '(1668167389) 193 days, 1:47:53.89',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2383669184',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:0F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '5589',
                        IFLASTCHANGE => '(1399398381) 161 days, 23:13:03.81',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '631494',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:10'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1638043019',
                        IFLASTCHANGE => '(1667752600) 193 days, 0:38:46.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '469166891',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:11'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4141) 0:00:41.41',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:12'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '884179267',
                        IFLASTCHANGE => '(1660466187) 192 days, 4:24:21.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3400637521',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:13'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '359416168',
                        IFLASTCHANGE => '(1668286829) 193 days, 2:07:48.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '756432620',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:14'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4142) 0:00:41.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:15'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '204828',
                        IFLASTCHANGE => '(1546204896) 178 days, 23:00:48.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '2257',
                        IFOUTOCTETS  => '2733536359',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:16'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4142) 0:00:41.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:17'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2724805151',
                        IFLASTCHANGE => '(182404430) 21 days, 2:40:44.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3155157885',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:18'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3914931489',
                        IFLASTCHANGE => '(16491) 0:02:44.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2654463940',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:19'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '6',
                        IFINOCTETS   => '2925623154',
                        IFLASTCHANGE => '(1366004940) 158 days, 2:27:29.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2183974366',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:1B:54:D6:39:1A'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.8.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'AP-74.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:CD:86:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            SNMPHOSTNAME => 'AP-74.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:CD:86:00',
            MODELSNMP    => 'Networking2179',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W1A2',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                FIRMWARE => '15.0(1)SE3',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.74' ]
                },
                MAC          => 'C4:0A:CB:CD:86:00',
                MANUFACTURER => 'Cisco',
                MEMORY       => 4,
                MODEL        => 'WS-C2960-48TC-L',
                NAME         => 'AP-74.mgmt.dauphine.fr',
                RAM          => 64,
                SERIAL       => 'FOC1511W1A2',
                TYPE         => 'NETWORKING',
                UPTIME       => '(347543457) 40 days, 5:23:54.57'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1474264407',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(33843) 0:05:38.43',
                        IFMTU            => '1500',
                        IFNAME           => 'Vl1',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '328275733',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)',
                        MAC              => 'C4:0A:CB:CD:86:40'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/1',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:01'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '236588628',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346931458) 40 days, 3:41:54.58',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/2',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1309670942',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:02'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '244400373',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346733109) 40 days, 3:08:51.09',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/3',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2758132634',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:03'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '306005406',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347248129) 40 days, 4:34:41.29',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/4',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2237159677',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:04'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '341205155',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346709972) 40 days, 3:04:59.72',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/5',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4244518876',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:05'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '103424675',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(299032702) 34 days, 14:38:47.02',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/6',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1103108996',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:06'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '384186304',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347364747) 40 days, 4:54:07.47',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/7',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '680410947',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:07'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(304905559) 35 days, 6:57:35.59',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/8',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '5306391',
                        IFOUTOCTETS      => '1711110227',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:08'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/9',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/9',
                        IFNUMBER         => '10009',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:09'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '352167261',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(199152305) 23 days, 1:12:03.05',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/10',
                        IFNUMBER         => '10010',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '472288711',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:0A'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/11',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/11',
                        IFNUMBER         => '10011',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:0B'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '947341952',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(292879038) 33 days, 21:33:10.38',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/12',
                        IFNUMBER         => '10012',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3871739267',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:0C'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/13',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4122) 0:00:41.22',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/13',
                        IFNUMBER         => '10013',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:0D'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '310298783',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347014191) 40 days, 3:55:41.91',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/14',
                        IFNUMBER         => '10014',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3190072208',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:0E'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/15',
                        IFNUMBER         => '10015',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:0F'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/16',
                        IFNUMBER         => '10016',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:10'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/17',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/17',
                        IFNUMBER         => '10017',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:11'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/18',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/18',
                        IFNUMBER         => '10018',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:12'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '257298363',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347064484) 40 days, 4:04:04.84',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/19',
                        IFNUMBER         => '10019',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '462767851',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:13'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '485150014',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(344231637) 39 days, 20:11:56.37',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/20',
                        IFNUMBER         => '10020',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2831486943',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:14'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '80068166',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(19407) 0:03:14.07',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/21',
                        IFNUMBER         => '10021',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3115275205',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:15'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/22',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/22',
                        IFNUMBER         => '10022',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:16'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/23',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '214483908',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(345462929) 39 days, 23:37:09.29',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/23',
                        IFNUMBER         => '10023',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1039775044',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:17'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/24',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/24',
                        IFNUMBER         => '10024',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:18'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/25',
                        IFINERRORS       => '10114',
                        IFINOCTETS       => '197928734',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347389474) 40 days, 4:58:14.74',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/25',
                        IFNUMBER         => '10025',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2278558878',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:19'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/26',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/26',
                        IFNUMBER         => '10026',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:1A'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/27',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '660664840',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17566) 0:02:55.66',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/27',
                        IFNUMBER         => '10027',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '189899557',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:1B'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/28',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '533303751',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346865571) 40 days, 3:30:55.71',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/28',
                        IFNUMBER         => '10028',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1170216684',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:1C'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/29',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '182135404',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346295021) 40 days, 1:55:50.21',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/29',
                        IFNUMBER         => '10029',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1274821872',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:1D'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/30',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/30',
                        IFNUMBER         => '10030',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:1E'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/31',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '29059300',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16871) 0:02:48.71',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/31',
                        IFNUMBER         => '10031',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '633177844',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:1F'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/32',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '214096311',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(223291471) 25 days, 20:15:14.71',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/32',
                        IFNUMBER         => '10032',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4206248334',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:20'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/33',
                        IFINERRORS       => '2369',
                        IFINOCTETS       => '95132469',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(320907355) 37 days, 3:24:33.55',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/33',
                        IFNUMBER         => '10033',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '587991352',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:21'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/34',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '489015270',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347143890) 40 days, 4:17:18.90',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/34',
                        IFNUMBER         => '10034',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1209925409',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:22'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/35',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/35',
                        IFNUMBER         => '10035',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:23'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/36',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '432349066',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347141430) 40 days, 4:16:54.30',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/36',
                        IFNUMBER         => '10036',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '427746098',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:24'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/37',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4123) 0:00:41.23',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/37',
                        IFNUMBER         => '10037',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:25'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/38',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '273611216',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(50167) 0:08:21.67',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/38',
                        IFNUMBER         => '10038',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3366833064',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:26'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/39',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '50812277',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(311161429) 36 days, 0:20:14.29',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/39',
                        IFNUMBER         => '10039',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '523659377',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:27'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/40',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/40',
                        IFNUMBER         => '10040',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:28'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/41',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/41',
                        IFNUMBER         => '10041',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:29'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/42',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '510737178',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(48708) 0:08:07.08',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/42',
                        IFNUMBER         => '10042',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3327711715',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:2A'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/43',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/43',
                        IFNUMBER         => '10043',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:2B'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/44',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '614324126',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(46296) 0:07:42.96',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/44',
                        IFNUMBER         => '10044',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1211817539',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:2C'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/45',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/45',
                        IFNUMBER         => '10045',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:2D'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/46',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/46',
                        IFNUMBER         => '10046',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:2E'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/47',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/47',
                        IFNUMBER         => '10047',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:2F'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/48',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/48',
                        IFNUMBER         => '10048',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:30'
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4124) 0:00:41.24',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi0/1',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:31'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:FD:94:09:B0', '00:0B:5F:CC:D8:80',
                                    '00:D0:95:17:51:A3', '00:D0:95:3E:96:80',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    '00:1A:6D:4F:6F:81', '00:07:E9:06:A6:BE',
                                    '00:09:43:09:04:18', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:2B:CC:E7',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3'
                                ]
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2071109510',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(33930) 0:05:39.30',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi0/2',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '275105132',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'C4:0A:CB:CD:86:32'
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.9.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => '64:D9:89:8D:B1:80',
            SNMPHOSTNAME => 'CB-C005-208.Dauphine',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => '64:D9:89:8D:B1:80',
            SNMPHOSTNAME => 'CB-C005-208.Dauphine',
            MODELSNMP    => 'Networking2179',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W19F',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                FIRMWARE     => '15.0(1)SE3',
                ID           => undef,
                MAC          => '64:D9:89:8D:B1:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 5,
                MODEL        => 'WS-C2960-48TC-L',
                NAME         => 'CB-C005-208.Dauphine',
                RAM          => 64,
                SERIAL       => 'FOC1511W19F',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2847919715',
                        IFLASTCHANGE => '(595775969) 68 days, 22:55:59.69',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2431876662',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '64:D9:89:8D:B1:C0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:81'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:82'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:83'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:84'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:85'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:86'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:87'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:88'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:89'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:8A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:8B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:8C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:8D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:8E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '2',
                        IFINOCTETS   => '158358580',
                        IFLASTCHANGE => '(1629636421) 188 days, 14:46:04.21',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2542256749',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:8F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:90'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4253) 0:00:42.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:91'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:92'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:93'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:94'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:95'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:96'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:97'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:98'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:99'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:9A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:9B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:9C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4254) 0:00:42.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:9D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:9E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:9F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A1'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A2'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A3'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A4'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A5'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A6'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A7'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A8'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4255) 0:00:42.55',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:A9'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:AA'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:AB'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:AC'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:AD'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:AE'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:AF'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:B0'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '627337006',
                        IFLASTCHANGE => '(595776056) 68 days, 22:56:00.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2755039325',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:B1'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4256) 0:00:42.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '64:D9:89:8D:B1:B2'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.10.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => '2C:36:F8:7D:09:00',
            SNMPHOSTNAME => 'CB-C005-206.Dauphine',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => '2C:36:F8:7D:09:00',
            SNMPHOSTNAME => 'CB-C005-206.Dauphine',
            MODELSNMP    => 'Networking2179',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCQ1605X4UZ',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                FIRMWARE     => '15.0(1)SE3',
                ID           => undef,
                MAC          => '2C:36:F8:7D:09:00',
                MANUFACTURER => 'Cisco',
                MEMORY       => 4,
                MODEL        => 'WS-C2960-48TC-L',
                NAME         => 'CB-C005-206.Dauphine',
                RAM          => 64,
                SERIAL       => 'FCQ1605X4UZ',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2876037603',
                        IFLASTCHANGE => '(596600541) 69 days, 1:13:25.41',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2448955914',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '2C:36:F8:7D:09:40'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:01'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:02'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:03'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:04'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:05'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:06'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:07'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:08'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:09'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:0A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4230) 0:00:42.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:0B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:0C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:0D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '13649415',
                        IFLASTCHANGE => '(1623443346) 187 days, 21:33:53.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '144458186',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:0E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:0F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:10'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '6301',
                        IFINOCTETS   => '1619463572',
                        IFLASTCHANGE => '(1626503610) 188 days, 6:03:56.10',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '977154644',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:11'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:12'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '3',
                        IFINOCTETS   => '2525677665',
                        IFLASTCHANGE => '(1633323510) 189 days, 1:00:35.10',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3438774464',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:13'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '2557592156',
                        IFLASTCHANGE => '(1633441760) 189 days, 1:20:17.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '36851033',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:14'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:15'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:16'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:17'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4231) 0:00:42.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:18'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '6',
                        IFINOCTETS   => '193179946',
                        IFLASTCHANGE => '(1600000985) 185 days, 4:26:49.85',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1349888727',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:19'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:1A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:1B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:1C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:1D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:1E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:1F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:20'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:21'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:22'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:23'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:24'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:25'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:26'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '13004',
                        IFINOCTETS   => '2100830282',
                        IFLASTCHANGE => '(1632988529) 189 days, 0:04:45.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2691288013',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:27'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:28'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:29'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:2A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:2B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:2C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:2D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1500391',
                        IFLASTCHANGE => '(1622956857) 187 days, 20:12:48.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '157324648',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:2E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:2F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:30'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:96', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1720265539',
                        IFLASTCHANGE => '(596600629) 69 days, 1:13:26.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2490856586',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:31'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4232) 0:00:42.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:09:32'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.11.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => '2C:36:F8:7D:06:80',
            SNMPHOSTNAME => 'CB-C005-207.Dauphine',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => '2C:36:F8:7D:06:80',
            SNMPHOSTNAME => 'CB-C005-207.Dauphine',
            MODELSNMP    => 'Networking2179',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FCQ1605X4VP',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                FIRMWARE     => '15.0(1)SE3',
                ID           => undef,
                MAC          => '2C:36:F8:7D:06:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 4,
                MODEL        => 'WS-C2960-48TC-L',
                NAME         => 'CB-C005-207.Dauphine',
                RAM          => 64,
                SERIAL       => 'FCQ1605X4VP',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2446137012',
                        IFLASTCHANGE => '(595957433) 68 days, 23:26:14.33',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2022849692',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '2C:36:F8:7D:06:C0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:81'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:82'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:83'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:84'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:85'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:86'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:87'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4162799898',
                        IFLASTCHANGE => '(1615911411) 187 days, 0:38:34.11',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2434568578',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:88'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '45',
                        IFINOCTETS   => '50514456',
                        IFLASTCHANGE => '(1615374157) 186 days, 23:09:01.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '148',
                        IFOUTOCTETS  => '3168236376',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:89'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:8A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:8B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '171288465',
                        IFLASTCHANGE => '(1623513609) 187 days, 21:45:36.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2095312613',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:8C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4123) 0:00:41.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:8D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '279026381',
                        IFLASTCHANGE => '(1486671356) 172 days, 1:38:33.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3945616377',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:8E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:8F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:90'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:91'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:92'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1354428366',
                        IFLASTCHANGE => '(1631466876) 188 days, 19:51:08.76',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2678286274',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:93'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:94'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:95'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:96'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:97'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:98'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:99'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4124) 0:00:41.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:9A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1354391915',
                        IFLASTCHANGE => '(1324013317) 153 days, 5:48:53.17',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1640684234',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:9B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:9C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1535589407',
                        IFLASTCHANGE => '(419610) 1:09:56.10',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2548890840',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:9D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:9E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:9F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A1'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A2'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A3'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A4'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A5'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A6'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A7'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4125) 0:00:41.25',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A8'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:A9'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:AA'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:AB'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:AC'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:AD'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:AE'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:AF'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:B0'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:83', '00:19:D1:92:0C:4C',
                                    'B4:14:89:38:2D:95', 'B8:AC:6F:94:57:ED',
                                    'E8:E7:32:27:23:5F', 'E8:E7:32:27:31:02',
                                    'E8:E7:32:27:38:30', 'E8:E7:32:27:63:A0',
                                    'E8:E7:32:27:63:F4', 'E8:E7:32:2A:E0:9E',
                                    'E8:E7:32:2A:E0:B6', 'E8:E7:32:2A:E8:A4',
                                    'E8:E7:32:2A:E8:BC', 'E8:E7:32:2B:C1:E2',
                                    'E8:E7:32:2B:C1:FB', 'E8:E7:32:4B:78:F8',
                                    'E8:E7:32:4B:79:13', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', 'E8:E7:32:5C:BE:D3'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3690690104',
                        IFLASTCHANGE => '(595957522) 68 days, 23:26:15.22',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3489062289',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:B1'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4126) 0:00:41.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '2C:36:F8:7D:06:B2'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.12.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => 'C4:0A:CB:22:E5:80',
            SNMPHOSTNAME => 'CB-C005-205.Dauphine',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
            MAC          => 'C4:0A:CB:22:E5:80',
            SNMPHOSTNAME => 'CB-C005-205.Dauphine',
            MODELSNMP    => 'Networking2179',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W1CB'
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2012 by Cisco Systems, Inc.
Compiled Wed 30-May-12 14:26 by prod_rel_team',
                FIRMWARE     => '15.0(1)SE3',
                ID           => undef,
                MAC          => 'C4:0A:CB:22:E5:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 4,
                MODEL        => 'WS-C2960-48TC-L',
                NAME         => 'CB-C005-205.Dauphine',
                RAM          => 64,
                SERIAL       => 'FOC1511W1CB',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2871212296',
                        IFLASTCHANGE => '(596609075) 69 days, 1:14:50.75',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2443338754',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => 'C4:0A:CB:22:E5:C0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:81'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:82'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:83'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:84'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:85'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:86'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:87'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4058) 0:00:40.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:88'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:89'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:8A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:8B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:8C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:8D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1544560270',
                        IFLASTCHANGE => '(1631510009) 188 days, 19:58:20.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '10994',
                        IFOUTOCTETS  => '3483278393',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:8E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:8F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '2724601483',
                        IFLASTCHANGE => '(1634398586) 189 days, 3:59:45.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '10943',
                        IFOUTOCTETS  => '2696552369',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:90'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:91'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:92'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:93'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:94'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4059) 0:00:40.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:95'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:96'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '174047329',
                        IFLASTCHANGE => '(1630510233) 188 days, 17:11:42.33',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '916141211',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:97'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:98'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '171612321',
                        IFLASTCHANGE => '(1630510161) 188 days, 17:11:41.61',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '993850547',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:99'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:9A'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:9B'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '787254341',
                        IFLASTCHANGE => '(1476276530) 170 days, 20:46:05.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1382513486',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:9C'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:9D'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '18309',
                        IFLASTCHANGE => '(1002540637) 116 days, 0:50:06.37',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '28180240',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:9E'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:9F'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1961',
                        IFLASTCHANGE => '(1002352522) 116 days, 0:18:45.22',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1145076',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A1'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '184171260',
                        IFLASTCHANGE => '(1630510297) 188 days, 17:11:42.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2034868762',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A2'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A3'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '6108',
                        IFLASTCHANGE => '(1002376442) 116 days, 0:22:44.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '10636434',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A4'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A5'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '229049',
                        IFLASTCHANGE => '(1580441927) 182 days, 22:06:59.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3882553',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A6'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A7'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A8'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:A9'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:AA'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:AB'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:AC'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:AD'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:AE'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:AF'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4060) 0:00:40.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:B0'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3',
                                    '00:0B:5F:CC:D8:80', '00:D0:95:17:51:A3',
                                    '00:D0:95:3E:96:80', '00:D0:95:3E:96:83',
                                    '00:19:D1:92:0C:4C', 'B4:14:89:38:2D:98',
                                    'B8:AC:6F:94:57:ED', 'E8:E7:32:27:23:5F',
                                    'E8:E7:32:27:31:02', 'E8:E7:32:27:38:30',
                                    'E8:E7:32:27:63:A0', 'E8:E7:32:27:63:F4',
                                    'E8:E7:32:2A:E0:9E', 'E8:E7:32:2A:E0:B6',
                                    'E8:E7:32:2A:E8:A4', 'E8:E7:32:2A:E8:BC',
                                    'E8:E7:32:2B:C1:E2', 'E8:E7:32:2B:C1:FB',
                                    'E8:E7:32:4B:78:F8', 'E8:E7:32:4B:79:13',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    'E8:E7:32:5C:BE:B8', 'E8:E7:32:5C:BE:D3'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1510685316',
                        IFLASTCHANGE => '(596609163) 69 days, 1:14:51.63',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4095281856',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:B1'
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4061) 0:00:40.61',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'C4:0A:CB:22:E5:B2'
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.20.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'CP-lt-40.mgmt.dauphine.fr',
            MAC          => '04:C5:A4:42:F2:80',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'CP-lt-40.mgmt.dauphine.fr',
            MAC          => '04:C5:A4:42:F2:80',
            MODELSNMP    => 'Networking2183',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1508V4B5',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
                CPU      => '97',
                FIRMWARE => 'CW_VERSION$12.2(50)SE5$',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.40' ]
                },
                MAC          => '04:C5:A4:42:F2:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 22,
                MODEL        => 'WS-C2960-8TC-S',
                NAME         => 'CP-lt-40.mgmt.dauphine.fr',
                RAM          => 64,
                SERIAL       => 'FOC1508V4B5',
                TYPE         => 'NETWORKING',
                UPTIME       => '(69260934) 8 days, 0:23:29.34'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1908443810',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4584) 0:00:45.84',
                        IFMTU            => '1500',
                        IFNAME           => 'Vl1',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '21744655',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)',
                        MAC              => '04:C5:A4:42:F2:C0'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1599380',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4688) 0:00:46.88',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/1',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '2330',
                        IFOUTOCTETS      => '61797424',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:81',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '658797',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4688) 0:00:46.88',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/2',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '2330',
                        IFOUTOCTETS      => '61239968',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:82',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/3',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:83',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/4',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:84',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/5',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:85',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/6',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:86',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4387) 0:00:43.87',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/7',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:87',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF'
                                ]
                            }
                        },
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '22175511',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(60319687) 6 days, 23:33:16.87',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/8',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2242606023',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:88',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'default',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.116',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CP1-CRIC-116.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '235512242',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4861) 0:00:48.61',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi0/1',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '47433441',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '04:C5:A4:42:F2:89',
                        TRUNK            => 1
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.21.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            MAC          => '04:C5:A4:42:F2:80',
            SNMPHOSTNAME => 'default-40.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            MAC          => '04:C5:A4:42:F2:80',
            SNMPHOSTNAME => 'default-40.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2183',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1508V4B5',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
                CPU          => '90',
                FIRMWARE     => 'CW_VERSION$12.2(50)SE5$',
                ID           => undef,
                MAC          => '04:C5:A4:42:F2:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 22,
                MODEL        => 'WS-C2960-8TC-S',
                NAME         => 'default-40.mgmt.dauphine.fr',
                RAM          => 64,
                SERIAL       => 'FOC1508V4B5',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2211338520',
                        IFLASTCHANGE => '(4765) 0:00:47.65',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '439636656',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '04:C5:A4:42:F2:C0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '77646872',
                        IFLASTCHANGE => '(1699518194) 196 days, 16:53:01.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '18',
                        IFOUTOCTETS  => '1451562620',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:81',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '48510643',
                        IFLASTCHANGE => '(4687) 0:00:46.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '18',
                        IFOUTOCTETS  => '1448479479',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:82',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4386) 0:00:43.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:83',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INFRA_SRV',
                                    NUMBER => '56'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4386) 0:00:43.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:84',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4386) 0:00:43.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:85',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4386) 0:00:43.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:86',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4386) 0:00:43.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:87',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'INALCO',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF',
                                    '78:FE:3D:D5:0E:FF', '78:FE:3D:D5:0E:FF'
                                ]
                            }
                        },
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '453028979',
                        IFLASTCHANGE => '(870221628) 100 days, 17:16:56.28',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2918695052',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:88',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'default',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.116',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CP1-CRIC-116.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2278713857',
                        IFLASTCHANGE => '(4859) 0:00:48.59',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1132732202',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '04:C5:A4:42:F2:89',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.22.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'Scol-tmp-65.mgmt.dauphine.fr',
            MAC          => 'E8:40:40:AA:73:80',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
            SNMPHOSTNAME => 'Scol-tmp-65.mgmt.dauphine.fr',
            MAC          => 'E8:40:40:AA:73:80',
            MODELSNMP    => 'Networking2183',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1511W532'
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Tue 28-Sep-10 13:44 by prod_rel_team',
                CPU          => '90',
                FIRMWARE     => 'CW_VERSION$12.2(50)SE5$',
                ID           => undef,
                MAC          => 'E8:40:40:AA:73:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 22,
                MODEL        => 'WS-C2960-8TC-S',
                NAME         => 'Scol-tmp-65.mgmt.dauphine.fr',
                RAM          => 64,
                SERIAL       => 'FOC1511W532',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '255556080',
                        IFLASTCHANGE => '(4851) 0:00:48.51',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '74494857',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => 'E8:40:40:AA:73:C0'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:81',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:82',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:83',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:84',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:85',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:86',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4449) 0:00:44.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:87',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4450) 0:00:44.50',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:88',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'DADM',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/13',
                                IP      => '192.168.1.51',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AP-Switch-51.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '478357725',
                        IFLASTCHANGE => '(5140) 0:00:51.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '85760601',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => 'E8:40:40:AA:73:89',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.24.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Fri 26-Mar-10 09:14 by prod_rel_team',
            SNMPHOSTNAME => 'AB-A422-7.mgmt.dauphine.fr',
            MAC          => '40:F4:EC:D6:80:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Fri 26-Mar-10 09:14 by prod_rel_team',
            SNMPHOSTNAME => 'AB-A422-7.mgmt.dauphine.fr',
            MAC          => '40:F4:EC:D6:80:00',
            MODELSNMP    => 'Networking2184',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1501V1PS'
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2010 by Cisco Systems, Inc.
Compiled Fri 26-Mar-10 09:14 by prod_rel_team',
                CPU      => '92',
                FIRMWARE => 'CW_VERSION$12.2(50)SE4$',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.7' ]
                },
                MAC          => '40:F4:EC:D6:80:00',
                MANUFACTURER => 'Cisco',
                MEMORY       => 23,
                MODEL        => 'WS-C2960-8TC-S',
                NAME         => 'AB-A422-7.mgmt.dauphine.fr',
                RAM          => 64,
                SERIAL       => 'FOC1501V1PS',
                TYPE         => 'NETWORKING',
                UPTIME       => '(1513179720) 175 days, 3:16:37.20'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2590321551',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(18565332) 2 days, 3:34:13.32',
                        IFMTU            => '1500',
                        IFNAME           => 'Vl1',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '745432723',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)',
                        MAC              => '40:F4:EC:D6:80:40'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '68126956',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1480962412) 171 days, 9:47:04.12',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/1',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1326656584',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:01',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0005',
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/2',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:02',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/3',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:03',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '2',
                        IFINOCTETS       => '2547705402',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1481346896) 171 days, 10:51:08.96',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/4',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '3607',
                        IFOUTOCTETS      => '2768496992',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:04',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/5',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:05',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/6',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:06',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/7',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:07',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4357) 0:00:43.57',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0/8',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:08',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'VLAN0007',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/1',
                                IP      => '192.168.1.1',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AB-Switch-1.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '1388411911',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(18565530) 2 days, 3:34:15.30',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi0/1',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3543298838',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => '40:F4:EC:D6:80:09',
                        TRUNK            => 1
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.25.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-72.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:E6:F0:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AP-72.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:E6:F0:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            SERIAL       => undef,
            FIRMWARE     => undef,
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU      => '88',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.72' ]
                },
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'AP-72.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING',
                UPTIME       => '(353824260) 40 days, 22:50:42.60'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1610116325',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(307811) 0:51:18.11',
                        IFMTU            => '1500',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '352821127',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4084) 0:00:40.84',
                        IFMTU            => '1500',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4084) 0:00:40.84',
                        IFMTU            => '1500',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '507105858',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(386721) 1:04:27.21',
                        IFMTU            => '1500',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '756332041',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '153360360',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(379789) 1:03:17.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3117649181',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '680518103',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(290882317) 33 days, 16:00:23.17',
                        IFMTU            => '1500',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2573011663',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4084) 0:00:40.84',
                        IFMTU            => '1500',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '671089899',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(388113) 1:04:41.13',
                        IFMTU            => '1500',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '504676058',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '4087007195',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(345475277) 39 days, 23:39:12.77',
                        IFMTU            => '1500',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3060679302',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/9',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2609224168',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(389128) 1:04:51.28',
                        IFMTU            => '1500',
                        IFNUMBER         => '10009',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3521084609',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '341404625',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347978569) 40 days, 6:36:25.69',
                        IFMTU            => '1500',
                        IFNUMBER         => '10010',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3580016358',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/11',
                        IFINERRORS       => '1515',
                        IFINOCTETS       => '132249879',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(320577812) 37 days, 2:29:38.12',
                        IFMTU            => '1500',
                        IFNUMBER         => '10011',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2442375155',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1067415000',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(321923662) 37 days, 6:13:56.62',
                        IFMTU            => '1500',
                        IFNUMBER         => '10012',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '812503561',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/13',
                        IFINERRORS       => '591',
                        IFINOCTETS       => '359121911',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(390800) 1:05:08.00',
                        IFMTU            => '1500',
                        IFNUMBER         => '10013',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3433514988',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '126151082',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(381013) 1:03:30.13',
                        IFMTU            => '1500',
                        IFNUMBER         => '10014',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2621084749',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFMTU            => '1500',
                        IFNUMBER         => '10015',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '166036634',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(353807472) 40 days, 22:47:54.72',
                        IFMTU            => '1500',
                        IFNUMBER         => '10016',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1799720061',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/17',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1791573126',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(321857204) 37 days, 6:02:52.04',
                        IFMTU            => '1500',
                        IFNUMBER         => '10017',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '823572932',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/18',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '254622153',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(353200430) 40 days, 21:06:44.30',
                        IFMTU            => '1500',
                        IFNUMBER         => '10018',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1058979164',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '303169302',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(349772612) 40 days, 11:35:26.12',
                        IFMTU            => '1500',
                        IFNUMBER         => '10019',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2456540728',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '48582706',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346052014) 40 days, 1:15:20.14',
                        IFMTU            => '1500',
                        IFNUMBER         => '10020',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '588495127',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '259332300',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(302480582) 35 days, 0:13:25.82',
                        IFMTU            => '1500',
                        IFNUMBER         => '10021',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '948041575',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/22',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1796339792',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(190731649) 22 days, 1:48:36.49',
                        IFMTU            => '1500',
                        IFNUMBER         => '10022',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2377537428',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/23',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFMTU            => '1500',
                        IFNUMBER         => '10023',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/24',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '321715531',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(294316242) 34 days, 1:32:42.42',
                        IFMTU            => '1500',
                        IFNUMBER         => '10024',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2995462255',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/25',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1139046158',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(392091) 1:05:20.91',
                        IFMTU            => '1500',
                        IFNUMBER         => '10025',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4061519092',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/26',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '897599736',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(353733331) 40 days, 22:35:33.31',
                        IFMTU            => '1500',
                        IFNUMBER         => '10026',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '608813461',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/27',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '363832282',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(391652) 1:05:16.52',
                        IFMTU            => '1500',
                        IFNUMBER         => '10027',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '84820619',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/28',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4086) 0:00:40.86',
                        IFMTU            => '1500',
                        IFNUMBER         => '10028',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/29',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFMTU            => '1500',
                        IFNUMBER         => '10029',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/30',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '501327004',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(353647873) 40 days, 22:21:18.73',
                        IFMTU            => '1500',
                        IFNUMBER         => '10030',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '175667222',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/31',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFMTU            => '1500',
                        IFNUMBER         => '10031',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/32',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFMTU            => '1500',
                        IFNUMBER         => '10032',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/33',
                        IFINERRORS       => '3',
                        IFINOCTETS       => '887485319',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(345958465) 40 days, 0:59:44.65',
                        IFMTU            => '1500',
                        IFNUMBER         => '10033',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2478842366',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/34',
                        IFINERRORS       => '2',
                        IFINOCTETS       => '209395032',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347817025) 40 days, 6:09:30.25',
                        IFMTU            => '1500',
                        IFNUMBER         => '10034',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1498951827',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/35',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4087) 0:00:40.87',
                        IFMTU            => '1500',
                        IFNUMBER         => '10035',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/36',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFMTU            => '1500',
                        IFNUMBER         => '10036',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/37',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '761494658',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(389135) 1:04:51.35',
                        IFMTU            => '1500',
                        IFNUMBER         => '10037',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '495223509',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/38',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFMTU            => '1500',
                        IFNUMBER         => '10038',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/39',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '42789040',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(388603) 1:04:46.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10039',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2042259921',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/40',
                        IFINERRORS       => '79',
                        IFINOCTETS       => '29303899',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(353495549) 40 days, 21:55:55.49',
                        IFMTU            => '1500',
                        IFNUMBER         => '10040',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '955469137',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/41',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4088) 0:00:40.88',
                        IFMTU            => '1500',
                        IFNUMBER         => '10041',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/42',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '715670159',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(379955) 1:03:19.55',
                        IFMTU            => '1500',
                        IFNUMBER         => '10042',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3890588264',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/43',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1838664412',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(225714255) 26 days, 2:59:02.55',
                        IFMTU            => '1500',
                        IFNUMBER         => '10043',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4125511793',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/44',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10044',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/45',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '305141295',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(387140) 1:04:31.40',
                        IFMTU            => '1500',
                        IFNUMBER         => '10045',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2806555706',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/46',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10046',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/47',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '122607678',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(314220564) 36 days, 8:50:05.64',
                        IFMTU            => '1500',
                        IFNUMBER         => '10047',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1393992022',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/48',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10048',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4089) 0:00:40.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/18',
                                IP      => '192.168.1.51',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AP-Switch-51.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2938291536',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(307810) 0:51:18.10',
                        IFMTU            => '1500',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3960287099',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.26.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-243.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:E6:E8:80',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-243.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:E6:E8:80',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU      => '86',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.243' ]
                },
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'CB-243.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING',
                UPTIME       => '(414811307) 48 days, 0:15:13.07'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1637558866',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(243112293) 28 days, 3:18:42.93',
                        IFMTU            => '1500',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '384759087',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFMTU            => '1500',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '497158253',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(413689479) 47 days, 21:08:14.79',
                        IFMTU            => '1500',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1780428234',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '83',
                        IFINOCTETS       => '1918969338',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(407759248) 47 days, 4:39:52.48',
                        IFMTU            => '1500',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1656161676',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '4'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1333512877',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(347322) 0:57:53.22',
                        IFMTU            => '1500',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '490902365',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(348425) 0:58:04.25',
                        IFMTU            => '1500',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2254790327',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '336681994',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79316261) 9 days, 4:19:22.61',
                        IFMTU            => '1500',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1735119533',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '57958882',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(286399865) 33 days, 3:33:18.65',
                        IFMTU            => '1500',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2537069231',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2472680676',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(64713) 0:10:47.13',
                        IFMTU            => '1500',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3964300497',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/9',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2661465463',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(351505) 0:58:35.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10009',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1478400263',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10010',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/11',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '70054628',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373737489) 43 days, 6:09:34.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10011',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2971444489',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(3972) 0:00:39.72',
                        IFMTU            => '1500',
                        IFNUMBER         => '10012',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/13',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '64724386',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(362636524) 41 days, 23:19:25.24',
                        IFMTU            => '1500',
                        IFNUMBER         => '10013',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3721224604',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '519576010',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(73773) 0:12:17.73',
                        IFMTU            => '1500',
                        IFNUMBER         => '10014',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2843625112',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1183137033',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(180357) 0:30:03.57',
                        IFMTU            => '1500',
                        IFNUMBER         => '10015',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2152244965',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1764424540',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(76978) 0:12:49.78',
                        IFMTU            => '1500',
                        IFNUMBER         => '10016',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3949275897',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/17',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1772331613',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(413488740) 47 days, 20:34:47.40',
                        IFMTU            => '1500',
                        IFNUMBER         => '10017',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4283714395',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/18',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '279675270',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(79221) 0:13:12.21',
                        IFMTU            => '1500',
                        IFNUMBER         => '10018',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '498238424',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2474377606',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(383011347) 44 days, 7:55:13.47',
                        IFMTU            => '1500',
                        IFNUMBER         => '10019',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2431666154',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFMTU            => '1500',
                        IFNUMBER         => '10020',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2145039748',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(414329586) 47 days, 22:54:55.86',
                        IFMTU            => '1500',
                        IFNUMBER         => '10021',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3739481889',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/22',
                        IFINERRORS       => '2253',
                        IFINOCTETS       => '910293590',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(413415234) 47 days, 20:22:32.34',
                        IFMTU            => '1500',
                        IFNUMBER         => '10022',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2921028326',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/23',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '2569301891',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(414100489) 47 days, 22:16:44.89',
                        IFMTU            => '1500',
                        IFNUMBER         => '10023',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3572352715',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/24',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10024',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/25',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '295295371',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(180952) 0:30:09.52',
                        IFMTU            => '1500',
                        IFNUMBER         => '10025',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3467943347',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/26',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(4032) 0:00:40.32',
                        IFMTU            => '1500',
                        IFNUMBER         => '10026',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/27',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '42248817',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(414019181) 47 days, 22:03:11.81',
                        IFMTU            => '1500',
                        IFNUMBER         => '10027',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2990042834',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/28',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10028',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/29',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '603870054',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(408542162) 47 days, 6:50:21.62',
                        IFMTU            => '1500',
                        IFNUMBER         => '10029',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2549513280',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/30',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '864068577',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(413100958) 47 days, 19:30:09.58',
                        IFMTU            => '1500',
                        IFNUMBER         => '10030',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '132773280',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/31',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10031',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/32',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10032',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/33',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '3354112056',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(413521427) 47 days, 20:40:14.27',
                        IFMTU            => '1500',
                        IFNUMBER         => '10033',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3851864674',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/34',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10034',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/35',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2267002087',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(137703129) 15 days, 22:30:31.29',
                        IFMTU            => '1500',
                        IFNUMBER         => '10035',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2603564766',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/36',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '3816451795',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(284034613) 32 days, 20:59:06.13',
                        IFMTU            => '1500',
                        IFNUMBER         => '10036',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2653475890',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '34'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/37',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10037',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/38',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(3894) 0:00:38.94',
                        IFMTU            => '1500',
                        IFNUMBER         => '10038',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/39',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1822106652',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(175648) 0:29:16.48',
                        IFMTU            => '1500',
                        IFNUMBER         => '10039',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1032818239',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/40',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '54822205',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(379363881) 43 days, 21:47:18.81',
                        IFMTU            => '1500',
                        IFNUMBER         => '10040',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3750350011',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/41',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10041',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/42',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10042',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/43',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10043',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/44',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10044',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/45',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '70248823',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(293128108) 33 days, 22:14:41.08',
                        IFMTU            => '1500',
                        IFNUMBER         => '10045',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4137997403',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/46',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1784',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(129384) 0:21:33.84',
                        IFMTU            => '1500',
                        IFNUMBER         => '10046',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '83984',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/47',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '150380800',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(413634665) 47 days, 20:59:06.65',
                        IFMTU            => '1500',
                        IFNUMBER         => '10047',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4260968015',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/48',
                        IFINERRORS       => '122',
                        IFINOCTETS       => '10167456',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(379351616) 43 days, 21:45:16.16',
                        IFMTU            => '1500',
                        IFNUMBER         => '10048',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '287093414',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet1/0/6',
                                IP      => '10.20.0.6',
                                MODEL   => 'cisco WS-C2960S-24TD-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 15.0(2)SE, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-LT-0-6.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1205874919',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(243112293) 28 days, 3:18:42.93',
                        IFMTU            => '1500',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2065905086',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.27.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-39.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:CD:83:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-39.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:CD:83:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            SERIAL       => undef,
            FIRMWARE     => undef,
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU      => '86',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.39' ]
                },
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'AB-39.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING',
                UPTIME       => '(399149124) 46 days, 4:44:51.24'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1646773241',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(19601) 0:03:16.01',
                        IFMTU            => '1500',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '329970936',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1077054481',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398986512) 46 days, 4:17:45.12',
                        IFMTU            => '1500',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1088658557',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '54313218',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(90068) 0:15:00.68',
                        IFMTU            => '1500',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3893544945',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4094) 0:00:40.94',
                        IFMTU            => '1500',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '11792',
                        IFINOCTETS       => '3179834',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(339058773) 39 days, 5:49:47.73',
                        IFMTU            => '1500',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '163540851',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1442348',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373402199) 43 days, 5:13:41.99',
                        IFMTU            => '1500',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '158749402',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFMTU            => '1500',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2017369650',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(274983991) 31 days, 19:50:39.91',
                        IFMTU            => '1500',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1932959363',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '135',
                        IFINOCTETS       => '391240957',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373287344) 43 days, 4:54:33.44',
                        IFMTU            => '1500',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1559704531',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/9',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFMTU            => '1500',
                        IFNUMBER         => '10009',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4095) 0:00:40.95',
                        IFMTU            => '1500',
                        IFNUMBER         => '10010',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/11',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '429124969',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(355831562) 41 days, 4:25:15.62',
                        IFMTU            => '1500',
                        IFNUMBER         => '10011',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '291591497',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '259419663',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373499748) 43 days, 5:29:57.48',
                        IFMTU            => '1500',
                        IFNUMBER         => '10012',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1742189833',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/13',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFMTU            => '1500',
                        IFNUMBER         => '10013',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '459538485',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(395997133) 45 days, 19:59:31.33',
                        IFMTU            => '1500',
                        IFNUMBER         => '10014',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3954590768',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1693076107',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(18205) 0:03:02.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10015',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2993571232',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '21782154',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(338548782) 39 days, 4:24:47.82',
                        IFMTU            => '1500',
                        IFNUMBER         => '10016',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3311245137',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/17',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '243936150',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373399296) 43 days, 5:13:12.96',
                        IFMTU            => '1500',
                        IFNUMBER         => '10017',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2320429264',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/18',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFMTU            => '1500',
                        IFNUMBER         => '10018',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFMTU            => '1500',
                        IFNUMBER         => '10019',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4096) 0:00:40.96',
                        IFMTU            => '1500',
                        IFNUMBER         => '10020',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '204126088',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(19761) 0:03:17.61',
                        IFMTU            => '1500',
                        IFNUMBER         => '10021',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1139583024',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/22',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '273076162',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(94903926) 10 days, 23:37:19.26',
                        IFMTU            => '1500',
                        IFNUMBER         => '10022',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '105263224',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/23',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(4009) 0:00:40.09',
                        IFMTU            => '1500',
                        IFNUMBER         => '10023',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/24',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '295041092',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(83794) 0:13:57.94',
                        IFMTU            => '1500',
                        IFNUMBER         => '10024',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1169521450',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/25',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '159279876',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398403951) 46 days, 2:40:39.51',
                        IFMTU            => '1500',
                        IFNUMBER         => '10025',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1299989040',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/26',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '154971075',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(83057) 0:13:50.57',
                        IFMTU            => '1500',
                        IFNUMBER         => '10026',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1462158495',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/27',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '177661203',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(372714182) 43 days, 3:19:01.82',
                        IFMTU            => '1500',
                        IFNUMBER         => '10027',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '94822713',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/28',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '2512344603',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(95601429) 11 days, 1:33:34.29',
                        IFMTU            => '1500',
                        IFNUMBER         => '10028',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2728136037',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/29',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFMTU            => '1500',
                        IFNUMBER         => '10029',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/30',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '92318275',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398124187) 46 days, 1:54:01.87',
                        IFMTU            => '1500',
                        IFNUMBER         => '10030',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1525456045',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/31',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4097) 0:00:40.97',
                        IFMTU            => '1500',
                        IFNUMBER         => '10031',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/32',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '230285879',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(396789246) 45 days, 22:11:32.46',
                        IFMTU            => '1500',
                        IFNUMBER         => '10032',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '644737321',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/33',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '166684226',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373799092) 43 days, 6:19:50.92',
                        IFMTU            => '1500',
                        IFNUMBER         => '10033',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3667580775',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/34',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '52192332',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(94510532) 10 days, 22:31:45.32',
                        IFMTU            => '1500',
                        IFNUMBER         => '10034',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '400503274',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/35',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '45344558',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(397607755) 46 days, 0:27:57.55',
                        IFMTU            => '1500',
                        IFNUMBER         => '10035',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3406155936',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/36',
                        IFINERRORS       => '131',
                        IFINOCTETS       => '57169',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(88446) 0:14:44.46',
                        IFMTU            => '1500',
                        IFNUMBER         => '10036',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '7049719',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/37',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '178030566',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(350712465) 40 days, 14:12:04.65',
                        IFMTU            => '1500',
                        IFNUMBER         => '10037',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3153998775',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/38',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '248645438',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(78723) 0:13:07.23',
                        IFMTU            => '1500',
                        IFNUMBER         => '10038',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4040756127',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/39',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFMTU            => '1500',
                        IFNUMBER         => '10039',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/40',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '929532514',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(346438944) 40 days, 2:19:49.44',
                        IFMTU            => '1500',
                        IFNUMBER         => '10040',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1935901378',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/41',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '208685915',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398827244) 46 days, 3:51:12.44',
                        IFMTU            => '1500',
                        IFNUMBER         => '10041',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1751732687',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/42',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4098) 0:00:40.98',
                        IFMTU            => '1500',
                        IFNUMBER         => '10042',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/43',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '19401258',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(638058) 1:46:20.58',
                        IFMTU            => '1500',
                        IFNUMBER         => '10043',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3382662662',
                        IFPORTDUPLEX     => '2',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/44',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '828169904',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(73934) 0:12:19.34',
                        IFMTU            => '1500',
                        IFNUMBER         => '10044',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2621710761',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/45',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16148) 0:02:41.48',
                        IFMTU            => '1500',
                        IFNUMBER         => '10045',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '7191',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/46',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(3929) 0:00:39.29',
                        IFMTU            => '1500',
                        IFNUMBER         => '10046',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/47',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFMTU            => '1500',
                        IFNUMBER         => '10047',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/48',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4099) 0:00:40.99',
                        IFMTU            => '1500',
                        IFNUMBER         => '10048',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '787976',
                        IFINOCTETS       => '2407842475',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(183826324) 21 days, 6:37:43.24',
                        IFMTU            => '1500',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '629744854',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/15',
                                IP      => '192.168.1.1',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AB-Switch-1.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '3464173483',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(19601) 0:03:16.01',
                        IFMTU            => '1500',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1089744093',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.28.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-35.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:95:39:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'AB-35.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:95:39:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            SERIAL       => undef,
            FIRMWARE     => undef,
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU      => '86',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.35' ]
                },
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'AB-35.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING',
                UPTIME       => '(399196332) 46 days, 4:52:43.32'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1648762067',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(397566922) 46 days, 0:21:09.22',
                        IFMTU            => '1500',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '327002474',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'FastEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFMTU            => '1500',
                        IFNUMBER         => '10001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '63981580',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(396563513) 45 days, 21:33:55.13',
                        IFMTU            => '1500',
                        IFNUMBER         => '10002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '937738588',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFMTU            => '1500',
                        IFNUMBER         => '10003',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '450344552',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398236494) 46 days, 2:12:44.94',
                        IFMTU            => '1500',
                        IFNUMBER         => '10004',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '3204214563',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '4'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/5',
                        IFINERRORS       => '2',
                        IFINOCTETS       => '38840233',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398401314) 46 days, 2:40:13.14',
                        IFMTU            => '1500',
                        IFNUMBER         => '10005',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '452614371',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(108190) 0:18:01.90',
                        IFMTU            => '1500',
                        IFNUMBER         => '10006',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '549493032',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4102) 0:00:41.02',
                        IFMTU            => '1500',
                        IFNUMBER         => '10007',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/8',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10008',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/9',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10009',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '67816202',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(350878119) 40 days, 14:39:41.19',
                        IFMTU            => '1500',
                        IFNUMBER         => '10010',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '327285714',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/11',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10011',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '650951580',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(120665) 0:20:06.65',
                        IFMTU            => '1500',
                        IFNUMBER         => '10012',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '394157597',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/13',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10013',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10014',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4103) 0:00:41.03',
                        IFMTU            => '1500',
                        IFNUMBER         => '10015',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFMTU            => '1500',
                        IFNUMBER         => '10016',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/17',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4104) 0:00:41.04',
                        IFMTU            => '1500',
                        IFNUMBER         => '10017',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/18',
                        IFINERRORS       => '6',
                        IFINOCTETS       => '187013600',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(398731456) 46 days, 3:35:14.56',
                        IFMTU            => '1500',
                        IFNUMBER         => '10018',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2869573976',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '60657',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(95642711) 11 days, 1:40:27.11',
                        IFMTU            => '1500',
                        IFNUMBER         => '10019',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '13077',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '129005432',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(279218937) 32 days, 7:36:29.37',
                        IFMTU            => '1500',
                        IFNUMBER         => '10020',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1026310893',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '16077838',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(345682468) 40 days, 0:13:44.68',
                        IFMTU            => '1500',
                        IFNUMBER         => '10021',
                        IFOUTERRORS      => '2',
                        IFOUTOCTETS      => '331384323',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/22',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '42629097',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(372688082) 43 days, 3:14:40.82',
                        IFMTU            => '1500',
                        IFNUMBER         => '10022',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2826019152',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/23',
                        IFINERRORS       => '2',
                        IFINOCTETS       => '9715655',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(10666876) 1 day, 5:37:48.76',
                        IFMTU            => '1500',
                        IFNUMBER         => '10023',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '90823211',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/24',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '491106439',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(105228) 0:17:32.28',
                        IFMTU            => '1500',
                        IFNUMBER         => '10024',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1386091241',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/25',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10025',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '32'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/26',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '357716310',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(373696278) 43 days, 6:02:42.78',
                        IFMTU            => '1500',
                        IFNUMBER         => '10026',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '206058251',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/27',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10027',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/28',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10028',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/29',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10029',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/30',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4105) 0:00:41.05',
                        IFMTU            => '1500',
                        IFNUMBER         => '10030',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/31',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10031',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/32',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1205439419',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(240662414) 27 days, 20:30:24.14',
                        IFMTU            => '1500',
                        IFNUMBER         => '10032',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2210751295',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/33',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10033',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/34',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10034',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/35',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10035',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '31'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/36',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '836343698',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(240527926) 27 days, 20:07:59.26',
                        IFMTU            => '1500',
                        IFNUMBER         => '10036',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4232137886',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '32'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/37',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '369211235',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(397557227) 46 days, 0:19:32.27',
                        IFMTU            => '1500',
                        IFNUMBER         => '10037',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2686165684',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/38',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4106) 0:00:41.06',
                        IFMTU            => '1500',
                        IFNUMBER         => '10038',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/39',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10039',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/40',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10040',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/41',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10041',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/42',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10042',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/43',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10043',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '49'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/44',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '87723288',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(375400086) 43 days, 10:46:40.86',
                        IFMTU            => '1500',
                        IFNUMBER         => '10044',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1614810966',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/45',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10045',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/46',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '288663124',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(338194023) 39 days, 3:25:40.23',
                        IFMTU            => '1500',
                        IFNUMBER         => '10046',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1813930953',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '6'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/47',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10047',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'FastEthernet0/48',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10048',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1,
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(4107) 0:00:41.07',
                        IFMTU            => '1500',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFPORTDUPLEX     => '1',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/2',
                                IP      => '192.168.1.1',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AB-Switch-1.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet0/2',
                        IFINERRORS       => '1',
                        IFINOCTETS       => '771322567',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(397566921) 46 days, 0:21:09.21',
                        IFMTU            => '1500',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1590529004',
                        IFPORTDUPLEX     => '3',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        TRUNK            => 1
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNUMBER         => '10501',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.29.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:CD:8B:80',
            SNMPHOSTNAME => 'CP-106.mgmt.dauphine.fr'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:CD:8B:80',
            SNMPHOSTNAME => 'CP-106.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU          => '82',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'CP-106.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '324306997',
                        IFLASTCHANGE => '(22495) 0:03:44.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '198326962',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '80308107',
                        IFLASTCHANGE => '(120329) 0:20:03.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1592600745',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '30585837',
                        IFLASTCHANGE => '(156236660) 18 days, 1:59:26.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '132128949',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '401747940',
                        IFLASTCHANGE => '(157187364) 18 days, 4:37:53.64',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1589500122',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4086) 0:00:40.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '159598301',
                        IFLASTCHANGE => '(147202045) 17 days, 0:53:40.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1870553961',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4086) 0:00:40.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '452391194',
                        IFLASTCHANGE => '(132931) 0:22:09.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3555848377',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '1073',
                        IFINOCTETS   => '137011271',
                        IFLASTCHANGE => '(157169607) 18 days, 4:34:56.07',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '172987482',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '84803097',
                        IFLASTCHANGE => '(136738) 0:22:47.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1950174094',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4087) 0:00:40.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '136356734',
                        IFLASTCHANGE => '(142474) 0:23:44.74',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1729236803',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '33108269',
                        IFLASTCHANGE => '(84365) 0:14:03.65',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '979250843',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '32554739',
                        IFLASTCHANGE => '(157208813) 18 days, 4:41:28.13',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1466664361',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4087) 0:00:40.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '182885356',
                        IFLASTCHANGE => '(155727668) 18 days, 0:34:36.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '11019714',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4088) 0:00:40.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '185618733',
                        IFLASTCHANGE => '(155897899) 18 days, 1:02:58.99',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1136058308',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '32667238',
                        IFLASTCHANGE => '(120072415) 13 days, 21:32:04.15',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1751606549',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '806805605',
                        IFLASTCHANGE => '(972962) 2:42:09.62',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '845501901',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4088) 0:00:40.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3511113674',
                        IFLASTCHANGE => '(159516) 0:26:35.16',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2955248708',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4089) 0:00:40.89',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3895288',
                        IFLASTCHANGE => '(129040) 0:21:30.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '415142315',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '639422648',
                        IFLASTCHANGE => '(154708286) 17 days, 21:44:42.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1583482082',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4089) 0:00:40.89',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4089) 0:00:40.89',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4029) 0:00:40.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '24'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '107351309',
                        IFLASTCHANGE => '(50226) 0:08:22.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1105193530',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4089) 0:00:40.89',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '24'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '259003',
                        IFLASTCHANGE => '(48414) 0:08:04.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '153717880',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4090) 0:00:40.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '10780724',
                        IFLASTCHANGE => '(148809907) 17 days, 5:21:39.07',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '199413415',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '76801671',
                        IFLASTCHANGE => '(88578895) 10 days, 6:03:08.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '325559206',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4090) 0:00:40.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '24'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2047445154',
                        IFLASTCHANGE => '(123585420) 14 days, 7:17:34.20',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '909692649',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '206712049',
                        IFLASTCHANGE => '(54324491) 6 days, 6:54:04.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '288470454',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '807464',
                        IFLASTCHANGE => '(1440739) 4:00:07.39',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '860035231',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '993714857',
                        IFLASTCHANGE => '(39253) 0:06:32.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '26334686',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(3919) 0:00:39.19',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '69855460',
                        IFLASTCHANGE => '(155765287) 18 days, 0:40:52.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '314016603',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '29'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/22',
                                IP      => '192.168.1.101',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CP-Switch-101.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '667860899',
                        IFLASTCHANGE => '(22495) 0:03:44.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1234036200',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.30.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:AB:68:80',
            SNMPHOSTNAME => 'AP-71.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:AB:68:80',
            SNMPHOSTNAME => 'AP-71.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef,
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU          => '83',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'AP-71.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '166336386',
                        IFLASTCHANGE => '(18742) 0:03:07.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '92223141',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '949969381',
                        IFLASTCHANGE => '(384320) 1:04:03.20',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '441295959',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '12485333',
                        IFLASTCHANGE => '(51159683) 5 days, 22:06:36.83',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '462928907',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '162391644',
                        IFLASTCHANGE => '(5877187) 16:19:31.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2027456597',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '502829',
                        IFLASTCHANGE => '(413977) 1:08:59.77',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '12616711',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1436417149',
                        IFLASTCHANGE => '(414385) 1:09:03.85',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3382839916',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '135900175',
                        IFLASTCHANGE => '(414101) 1:09:01.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2459505968',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '110108413',
                        IFLASTCHANGE => '(79551102) 9 days, 4:58:31.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1672644216',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '249425464',
                        IFLASTCHANGE => '(391184) 1:05:11.84',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4177097156',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '28'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '95344638',
                        IFLASTCHANGE => '(412878) 1:08:48.78',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1010945089',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '62480892',
                        IFLASTCHANGE => '(71212257) 8 days, 5:48:42.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '850459015',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2006974792',
                        IFLASTCHANGE => '(411787) 1:08:37.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2379000962',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4563711',
                        IFLASTCHANGE => '(11117687) 1 day, 6:52:56.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '219374044',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '39828973',
                        IFLASTCHANGE => '(71113114) 8 days, 5:32:11.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '415391758',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '15'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '10411413',
                        IFLASTCHANGE => '(72050738) 8 days, 8:08:27.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '210423630',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '15360300',
                        IFLASTCHANGE => '(78218157) 9 days, 1:16:21.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '474',
                        IFOUTOCTETS  => '65411852',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.13',
                                MODEL   => 'cisco WS-C2960-8TC-S',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE5, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'AP-A410-13.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1199196918',
                        IFLASTCHANGE => '(402301) 1:07:03.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3964600438',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/17',
                                IP      => '192.168.1.51',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AP-Switch-51.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '2969359472',
                        IFLASTCHANGE => '(18742) 0:03:07.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2308685046',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.32.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:CD:88:00',
            SNMPHOSTNAME => 'CP-129.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:CD:88:00',
            SNMPHOSTNAME => 'CP-129.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU          => '90',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'CP-129.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '342494300',
                        IFLASTCHANGE => '(4818) 0:00:48.18',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '209672405',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '139092153',
                        IFLASTCHANGE => '(155851887) 18 days, 0:55:18.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1742419228',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4067) 0:00:40.67',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '189',
                        IFINOCTETS   => '71450121',
                        IFLASTCHANGE => '(157084500) 18 days, 4:20:45.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '532210388',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '430952526',
                        IFLASTCHANGE => '(19905) 0:03:19.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2153282605',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '253409112',
                        IFLASTCHANGE => '(42446) 0:07:04.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2083166134',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4067) 0:00:40.67',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4068) 0:00:40.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4068) 0:00:40.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '74',
                        IFINOCTETS   => '7036113',
                        IFLASTCHANGE => '(11551577) 1 day, 8:05:15.77',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '46155745',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '303791372',
                        IFLASTCHANGE => '(25805) 0:04:18.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1572003616',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '21173022',
                        IFLASTCHANGE => '(36176409) 4 days, 4:29:24.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '104717078',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '529422442',
                        IFLASTCHANGE => '(156473469) 18 days, 2:38:54.69',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1497067739',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '269553',
                        IFLASTCHANGE => '(27594771) 3 days, 4:39:07.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '556202230',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4068) 0:00:40.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '290650374',
                        IFLASTCHANGE => '(156881980) 18 days, 3:46:59.80',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '942669195',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '425593965',
                        IFLASTCHANGE => '(155152038) 17 days, 22:58:40.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1082667493',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '85600087',
                        IFLASTCHANGE => '(61871) 0:10:18.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '415511032',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4069) 0:00:40.69',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1101020097',
                        IFLASTCHANGE => '(157014166) 18 days, 4:09:01.66',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1273830488',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4069) 0:00:40.69',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4174769',
                        IFLASTCHANGE => '(494680) 1:22:26.80',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '8081125',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '219300370',
                        IFLASTCHANGE => '(156492827) 18 days, 2:42:08.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1310224702',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '182718884',
                        IFLASTCHANGE => '(156722698) 18 days, 3:20:26.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1083092560',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '35025856',
                        IFLASTCHANGE => '(70020985) 8 days, 2:30:09.85',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '589031780',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '230329713',
                        IFLASTCHANGE => '(70814) 0:11:48.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3842105064',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '904740817',
                        IFLASTCHANGE => '(156472527) 18 days, 2:38:45.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1522207991',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '54802860',
                        IFLASTCHANGE => '(18502) 0:03:05.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '566699409',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '639159257',
                        IFLASTCHANGE => '(78322684) 9 days, 1:33:46.84',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1673881452',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4070) 0:00:40.70',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '174439316',
                        IFLASTCHANGE => '(44233383) 5 days, 2:52:13.83',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '333305315',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '3'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '213617248',
                        IFLASTCHANGE => '(155164185) 17 days, 23:00:41.85',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1165949405',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '221363175',
                        IFLASTCHANGE => '(148619821) 17 days, 4:49:58.21',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2459270527',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4071) 0:00:40.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '255905393',
                        IFLASTCHANGE => '(66105) 0:11:01.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2966830873',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1866640217',
                        IFLASTCHANGE => '(15690) 0:02:36.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3051142050',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4071) 0:00:40.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '357067127',
                        IFLASTCHANGE => '(156105339) 18 days, 1:37:33.39',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1322368606',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4071) 0:00:40.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2531683071',
                        IFLASTCHANGE => '(156408486) 18 days, 2:28:04.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4131182755',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4072) 0:00:40.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4072) 0:00:40.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4072) 0:00:40.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/11',
                                IP      => '192.168.1.101',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CP-Switch-101.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '1843027809',
                        IFLASTCHANGE => '(79048) 0:13:10.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2395085022',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.33.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:BA:6C:00',
            SNMPHOSTNAME => 'AP-73.mgmt.dauphine.fr',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            MAC          => 'C4:0A:CB:BA:6C:00',
            SNMPHOSTNAME => 'AP-73.mgmt.dauphine.fr',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU          => '91',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'AP-73.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '144407765',
                        IFLASTCHANGE => '(187468) 0:31:14.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '83035701',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '72026347',
                        IFLASTCHANGE => '(69851016) 8 days, 2:01:50.16',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '551563172',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '5751709',
                        IFLASTCHANGE => '(2482988) 6:53:49.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '180494199',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '527872396',
                        IFLASTCHANGE => '(714923) 1:59:09.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2127212600',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '268465910',
                        IFLASTCHANGE => '(62551534) 7 days, 5:45:15.34',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1544870396',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1256518',
                        IFLASTCHANGE => '(2650923) 7:21:49.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '138162383',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '178580626',
                        IFLASTCHANGE => '(61877376) 7 days, 3:52:53.76',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1013155442',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '236325752',
                        IFLASTCHANGE => '(68379177) 7 days, 21:56:31.77',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1049235021',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '44846590',
                        IFLASTCHANGE => '(71218823) 8 days, 5:49:48.23',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1205965751',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '140246634',
                        IFLASTCHANGE => '(70400905) 8 days, 3:33:29.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '907775152',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4091) 0:00:40.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4092) 0:00:40.92',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '98005676',
                        IFLASTCHANGE => '(720940) 2:00:09.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '472359628',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4092) 0:00:40.92',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4092) 0:00:40.92',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4092) 0:00:40.92',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '145683637',
                        IFLASTCHANGE => '(71289318) 8 days, 6:01:33.18',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1238652232',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4092) 0:00:40.92',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '280071751',
                        IFLASTCHANGE => '(722434) 2:00:24.34',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1727731681',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '93118465',
                        IFLASTCHANGE => '(70989573) 8 days, 5:11:35.73',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '216068348',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '358479611',
                        IFLASTCHANGE => '(69618960) 8 days, 1:23:09.60',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '75384595',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '6781078',
                        IFLASTCHANGE => '(70789112) 8 days, 4:38:11.12',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '643522671',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '113916008',
                        IFLASTCHANGE => '(779595) 2:09:55.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '741613119',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4093) 0:00:40.93',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '7992856',
                        IFLASTCHANGE => '(69389190) 8 days, 0:44:51.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '241156515',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '198',
                        IFINOCTETS   => '189882779',
                        IFLASTCHANGE => '(785572) 2:10:55.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1817390113',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '6932449',
                        IFLASTCHANGE => '(37007231) 4 days, 6:47:52.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '108639740',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '68568863',
                        IFLASTCHANGE => '(735646) 2:02:36.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '750136193',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4094) 0:00:40.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '28'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '50578752',
                        IFLASTCHANGE => '(63540286) 7 days, 8:30:02.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '485644142',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '76692457',
                        IFLASTCHANGE => '(68243810) 7 days, 21:33:58.10',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '318157013',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4095) 0:00:40.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '149910350',
                        IFLASTCHANGE => '(796874) 2:12:48.74',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1121153068',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '16'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '112096126',
                        IFLASTCHANGE => '(71436134) 8 days, 6:26:01.34',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '508696340',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '2172',
                        IFINOCTETS   => '26357827',
                        IFLASTCHANGE => '(45330644) 5 days, 5:55:06.44',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '397895750',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '76860575',
                        IFLASTCHANGE => '(70794781) 8 days, 4:39:07.81',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '580114711',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '27'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4563813',
                        IFLASTCHANGE => '(71039024) 8 days, 5:19:50.24',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '56826608',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '33'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/9',
                                IP      => '192.168.1.51',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AP-Switch-51.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2035232519',
                        IFLASTCHANGE => '(187467) 0:31:14.67',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3071486535',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.35.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-138.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:BA:6E:80',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CP-138.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:BA:6E:80',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU          => '89',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'CP-138.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '303984672',
                        IFLASTCHANGE => '(27650) 0:04:36.50',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '166297533',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '9',
                        IFINOCTETS   => '1567',
                        IFLASTCHANGE => '(74303921) 8 days, 14:23:59.21',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '8164',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '9605270',
                        IFLASTCHANGE => '(25410380) 2 days, 22:35:03.80',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '144881846',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '3'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '83024961',
                        IFLASTCHANGE => '(155288548) 17 days, 23:21:25.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '840720064',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '17'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '18024168',
                        IFLASTCHANGE => '(737161) 2:02:51.61',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '4',
                        IFOUTOCTETS  => '612976902',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4096) 0:00:40.96',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1996365421',
                        IFLASTCHANGE => '(56846) 0:09:28.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2953355851',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '10'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '17'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4097) 0:00:40.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3722663305',
                        IFLASTCHANGE => '(17536643) 2 days, 0:42:46.43',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '216745396',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '438974108',
                        IFLASTCHANGE => '(605618) 1:40:56.18',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '46574638',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '323761022',
                        IFLASTCHANGE => '(155053926) 17 days, 22:42:19.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1286935100',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2089262099',
                        IFLASTCHANGE => '(91637) 0:15:16.37',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '724058817',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '63656455',
                        IFLASTCHANGE => '(146401629) 16 days, 22:40:16.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '910962138',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1199538826',
                        IFLASTCHANGE => '(89253) 0:14:52.53',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '273047875',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '25004481',
                        IFLASTCHANGE => '(38687) 0:06:26.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '573755015',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '182373565',
                        IFLASTCHANGE => '(147846818) 17 days, 2:41:08.18',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1676447716',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4098) 0:00:40.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '374269884',
                        IFLASTCHANGE => '(36132) 0:06:01.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2167847608',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4099) 0:00:40.99',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4071) 0:00:40.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4099) 0:00:40.99',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '542617952',
                        IFLASTCHANGE => '(32650) 0:05:26.50',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1581335281',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4099) 0:00:40.99',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '433267145',
                        IFLASTCHANGE => '(156293986) 18 days, 2:08:59.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2151514332',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4099) 0:00:40.99',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4099) 0:00:40.99',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '5'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '15301257',
                        IFLASTCHANGE => '(27041) 0:04:30.41',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '987991758',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '173968322',
                        IFLASTCHANGE => '(156383003) 18 days, 2:23:50.03',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1331270132',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '11'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.117',
                                MODEL   => 'cisco WS-C2960-8TC-S',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANLITEK9-M), Version 12.2(50)SE4, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'cp-c202-117.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2499737889',
                        IFLASTCHANGE => '(741847) 2:03:38.47',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3095839272',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/1',
                                IP      => '192.168.1.101',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CP-Switch-101.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '496411095',
                        IFLASTCHANGE => '(27649) 0:04:36.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1605672412',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960.45.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-242.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:CD:73:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
            SNMPHOSTNAME => 'CB-242.mgmt.dauphine.fr',
            MAC          => 'C4:0A:CB:CD:73:00',
            MODELSNMP    => 'Networking2416',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => undef
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(50)SE, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2009 by Cisco Systems, Inc.
Compiled Fri 27-Feb-09 23:25 by weiliu',
                CPU          => '85',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 20,
                MODEL        => undef,
                NAME         => 'CB-242.mgmt.dauphine.fr',
                RAM          => 60,
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '300080287',
                        IFLASTCHANGE => '(22766) 0:03:47.66',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '172208712',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'FastEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '453610701',
                        IFLASTCHANGE => '(139444383) 16 days, 3:20:43.83',
                        IFMTU        => '1500',
                        IFNUMBER     => '10001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '629265435',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '100658373',
                        IFLASTCHANGE => '(131891494) 15 days, 6:21:54.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '10002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1671955162',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '81635731',
                        IFLASTCHANGE => '(139325168) 16 days, 3:00:51.68',
                        IFMTU        => '1500',
                        IFNUMBER     => '10003',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '721368132',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/4',
                        IFINERRORS   => '6914',
                        IFINOCTETS   => '442614632',
                        IFLASTCHANGE => '(78971488) 9 days, 3:21:54.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10004',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '964540942',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '6206231',
                        IFLASTCHANGE => '(138456745) 16 days, 0:36:07.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '10005',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '196349687',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '12'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10006',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4100) 0:00:41.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10007',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4101) 0:00:41.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10008',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '48714255',
                        IFLASTCHANGE => '(139408772) 16 days, 3:14:47.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '10009',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '477652625',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4101) 0:00:41.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10010',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4101) 0:00:41.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10011',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '44859074',
                        IFLASTCHANGE => '(67800) 0:11:18.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10012',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2064157133',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '116089383',
                        IFLASTCHANGE => '(18714) 0:03:07.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '10013',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '964695197',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '17508052',
                        IFLASTCHANGE => '(139092906) 16 days, 2:22:09.06',
                        IFMTU        => '1500',
                        IFNUMBER     => '10014',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1729384683',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3871580',
                        IFLASTCHANGE => '(139462818) 16 days, 3:23:48.18',
                        IFMTU        => '1500',
                        IFNUMBER     => '10015',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '168350925',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/16',
                        IFINERRORS   => '167',
                        IFINOCTETS   => '218976080',
                        IFLASTCHANGE => '(69354) 0:11:33.54',
                        IFMTU        => '1500',
                        IFNUMBER     => '10016',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2576771140',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '141788121',
                        IFLASTCHANGE => '(20313) 0:03:23.13',
                        IFMTU        => '1500',
                        IFNUMBER     => '10017',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1264175906',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/18',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '16996497',
                        IFLASTCHANGE => '(7449813) 20:41:38.13',
                        IFMTU        => '1500',
                        IFNUMBER     => '10018',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '92629868',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '105439303',
                        IFLASTCHANGE => '(139323602) 16 days, 3:00:36.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10019',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '607798846',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(72188) 0:12:01.88',
                        IFMTU        => '1500',
                        IFNUMBER     => '10020',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1600939431',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '12315440',
                        IFLASTCHANGE => '(139440727) 16 days, 3:20:07.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '10021',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '120816864',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4102) 0:00:41.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10022',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/23',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '85734537',
                        IFLASTCHANGE => '(139254244) 16 days, 2:49:02.44',
                        IFMTU        => '1500',
                        IFNUMBER     => '10023',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '265281199',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4102) 0:00:41.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10024',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '82610105',
                        IFLASTCHANGE => '(139666397) 16 days, 3:57:43.97',
                        IFMTU        => '1500',
                        IFNUMBER     => '10025',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '763921883',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4102) 0:00:41.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10026',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '856010',
                        IFLASTCHANGE => '(139106452) 16 days, 2:24:24.52',
                        IFMTU        => '1500',
                        IFNUMBER     => '10027',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '175717781',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '312293972',
                        IFLASTCHANGE => '(79590) 0:13:15.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '10028',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2541056794',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '10798153',
                        IFLASTCHANGE => '(130439269) 15 days, 2:19:52.69',
                        IFMTU        => '1500',
                        IFNUMBER     => '10029',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '197359629',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '14'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4102) 0:00:41.02',
                        IFMTU        => '1500',
                        IFNUMBER     => '10030',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '617539036',
                        IFLASTCHANGE => '(138800437) 16 days, 1:33:24.37',
                        IFMTU        => '1500',
                        IFNUMBER     => '10031',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2442221119',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3197737525',
                        IFLASTCHANGE => '(7474315) 20:45:43.15',
                        IFMTU        => '1500',
                        IFNUMBER     => '10032',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '359750722',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4103) 0:00:41.03',
                        IFMTU        => '1500',
                        IFNUMBER     => '10033',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4103) 0:00:41.03',
                        IFMTU        => '1500',
                        IFNUMBER     => '10034',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '253432783',
                        IFLASTCHANGE => '(130297867) 15 days, 1:56:18.67',
                        IFMTU        => '1500',
                        IFNUMBER     => '10035',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2591364469',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4103) 0:00:41.03',
                        IFMTU        => '1500',
                        IFNUMBER     => '10036',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '10237437',
                        IFLASTCHANGE => '(114468309) 13 days, 5:58:03.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10037',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '467768677',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '23'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3268485606',
                        IFLASTCHANGE => '(76485) 0:12:44.85',
                        IFMTU        => '1500',
                        IFNUMBER     => '10038',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1987657403',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '132713426',
                        IFLASTCHANGE => '(136478837) 15 days, 19:06:28.37',
                        IFMTU        => '1500',
                        IFNUMBER     => '10039',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '752647438',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '13'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '280970614',
                        IFLASTCHANGE => '(74130) 0:12:21.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10040',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2308082524',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '161291696',
                        IFLASTCHANGE => '(21973) 0:03:39.73',
                        IFMTU        => '1500',
                        IFNUMBER     => '10041',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2383663130',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '17192636',
                        IFLASTCHANGE => '(136582137) 15 days, 19:23:41.37',
                        IFMTU        => '1500',
                        IFNUMBER     => '10042',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '415598941',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4104) 0:00:41.04',
                        IFMTU        => '1500',
                        IFNUMBER     => '10043',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '12'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4104) 0:00:41.04',
                        IFMTU        => '1500',
                        IFNUMBER     => '10044',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '25'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/45',
                        IFINERRORS   => '4',
                        IFINOCTETS   => '4971345',
                        IFLASTCHANGE => '(111862391) 12 days, 22:43:43.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10045',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '115887726',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '55'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4104) 0:00:41.04',
                        IFMTU        => '1500',
                        IFNUMBER     => '10046',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '49'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4104) 0:00:41.04',
                        IFMTU        => '1500',
                        IFNUMBER     => '10047',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'FastEthernet0/48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4105) 0:00:41.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10048',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1,
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => undef,
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(4105) 0:00:41.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'FastEthernet0/3',
                                IP      => '192.168.1.201',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB-Switch-201.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '1476778337',
                        IFLASTCHANGE => '(22765) 0:03:47.65',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1630085818',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '10501',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    }
                ]
            }
        }
    ],
    'cisco/C2960S.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'SALSERV-INTERUFR-149.mgmt.dauphine.fr',
            MAC          => '18:33:9D:E7:15:00',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'SALSERV-INTERUFR-149.mgmt.dauphine.fr',
            MAC          => '18:33:9D:E7:15:00',
            MODELSNMP    => 'Networking2147',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1622Y2ME',
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
                FIRMWARE     => '12.2(58)SE1',
                ID           => undef,
                MAC          => '18:33:9D:E7:15:00',
                MANUFACTURER => 'Cisco',
                MEMORY       => 34,
                MODEL        => 'WS-C2960S-24TD-L',
                NAME         => 'SALSERV-INTERUFR-149.mgmt.dauphine.fr',
                RAM          => 128,
                SERIAL       => 'FOC1622Y2ME',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '398583684',
                        IFLASTCHANGE => '(10244) 0:01:42.44',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '18:33:9D:E7:15:40'
                    },
                    {
                        IFDESCR      => 'StackPort1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(9407) 0:01:34.07',
                        IFMTU        => '0',
                        IFNUMBER     => '5137',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '0',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'StackSub-St1-1',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFNUMBER     => '5138',
                        IFSPEED      => '0',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        IFDESCR      => 'StackSub-St1-2',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFNUMBER     => '5139',
                        IFSPEED      => '0',
                        IFTYPE       => 'propVirtual(53)'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'E4:11:5B:B0:2A:04', 'E4:11:5B:B0:2A:04',
                                    'E4:11:5B:B0:2A:04', 'E4:11:5B:B0:2A:04',
                                    'E4:11:5B:B0:2A:04', 'E4:11:5B:B0:2A:04'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3721685913',
                        IFLASTCHANGE => '(1104746783) 127 days, 20:44:27.83',
                        IFMTU        => '1500',
                        IFNUMBER     => '10101',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2392162814',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:01',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'E4:11:5B:B0:2A:02', 'E4:11:5B:B0:2A:02',
                                    'E4:11:5B:B0:2A:02', 'E4:11:5B:B0:2A:02',
                                    'E4:11:5B:B0:2A:02', 'E4:11:5B:B0:2A:02'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3748004083',
                        IFLASTCHANGE => '(1104746787) 127 days, 20:44:27.87',
                        IFMTU        => '1500',
                        IFNUMBER     => '10102',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2397581446',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:02',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'E4:11:5B:B0:2A:00', 'E4:11:5B:B0:2A:00',
                                    'E4:11:5B:B0:2A:00', 'E4:11:5B:B0:2A:00',
                                    'E4:11:5B:B0:2A:00', 'E4:11:5B:B0:2A:00'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3523074278',
                        IFLASTCHANGE => '(1104746779) 127 days, 20:44:27.79',
                        IFMTU        => '1500',
                        IFNUMBER     => '10103',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2393229184',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:03',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'E4:11:5B:B0:29:FE', 'E4:11:5B:B0:29:FE',
                                    'E4:11:5B:B0:29:FE', 'E4:11:5B:B0:29:FE',
                                    'E4:11:5B:B0:29:FE', 'E4:11:5B:B0:29:FE'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '23396375',
                        IFLASTCHANGE => '(1104746771) 127 days, 20:44:27.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '10104',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2306109186',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:04',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'GigabitEthernet1/0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '522870153',
                        IFLASTCHANGE => '(373533695) 43 days, 5:35:36.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10105',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2983152425',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:05',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'GigabitEthernet1/0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '536122690',
                        IFLASTCHANGE => '(380945737) 44 days, 2:10:57.37',
                        IFMTU        => '1500',
                        IFNUMBER     => '10106',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '788830719',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:06',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'GigabitEthernet1/0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '506922626',
                        IFLASTCHANGE => '(373780695) 43 days, 6:16:46.95',
                        IFMTU        => '1500',
                        IFNUMBER     => '10107',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '872891421',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:07',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:25:B3:AA:D6:B6', '00:25:B3:AA:D6:B6',
                                    '00:25:B3:AA:D6:B6', '00:25:B3:AA:D6:B6',
                                    '00:25:B3:AA:D6:B6', '00:25:B3:AA:D6:B6'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '771500355',
                        IFLASTCHANGE => '(1055146030) 122 days, 2:57:40.30',
                        IFMTU        => '1500',
                        IFNUMBER     => '10108',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3183168193',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:08',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'B4:99:BA:C0:EB:AA', 'B4:99:BA:C0:EB:AA',
                                    'B4:99:BA:C0:EB:AA', 'B4:99:BA:C0:EB:AA',
                                    'B4:99:BA:C0:EB:AA', 'B4:99:BA:C0:EB:AA'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3891929713',
                        IFLASTCHANGE => '(1081986747) 125 days, 5:31:07.47',
                        IFMTU        => '1500',
                        IFNUMBER     => '10109',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2400347595',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:09',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'B4:99:BA:C0:EB:A4', 'B4:99:BA:C0:EB:A4',
                                    'B4:99:BA:C0:EB:A4', 'B4:99:BA:C0:EB:A4',
                                    'B4:99:BA:C0:EB:A4', 'B4:99:BA:C0:EB:A4'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3952228784',
                        IFLASTCHANGE => '(1081986740) 125 days, 5:31:07.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '10110',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1919933645',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:0A',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'B4:99:BA:C0:EB:A8', 'B4:99:BA:C0:EB:A8',
                                    'B4:99:BA:C0:EB:A8', 'B4:99:BA:C0:EB:A8',
                                    'B4:99:BA:C0:EB:A8', 'B4:99:BA:C0:EB:A8'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '7357088',
                        IFLASTCHANGE => '(1081986791) 125 days, 5:31:07.91',
                        IFMTU        => '1500',
                        IFNUMBER     => '10111',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2403692200',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:0B',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    'B4:99:BA:C0:EB:A6', 'B4:99:BA:C0:EB:A6',
                                    'B4:99:BA:C0:EB:A6', 'B4:99:BA:C0:EB:A6',
                                    'B4:99:BA:C0:EB:A6', 'B4:99:BA:C0:EB:A6'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '15273278',
                        IFLASTCHANGE => '(1081986735) 125 days, 5:31:07.35',
                        IFMTU        => '1500',
                        IFNUMBER     => '10112',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2411515445',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:0C',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '78:E3:B5:12:97:DA', '78:E3:B5:12:97:DA',
                                    '78:E3:B5:12:97:DA', '78:E3:B5:12:97:DA',
                                    '78:E3:B5:12:97:DA', '78:E3:B5:12:97:DA'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '256594457',
                        IFLASTCHANGE => '(1080518701) 125 days, 1:26:27.01',
                        IFMTU        => '1500',
                        IFNUMBER     => '10113',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2398571120',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:0D',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '78:E3:B5:12:A7:08', '78:E3:B5:12:A7:08',
                                    '78:E3:B5:12:A7:08', '78:E3:B5:12:A7:08',
                                    '78:E3:B5:12:A7:08', '78:E3:B5:12:A7:08'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1092127028',
                        IFLASTCHANGE => '(1080518705) 125 days, 1:26:27.05',
                        IFMTU        => '1500',
                        IFNUMBER     => '10114',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2387872550',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:0E',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '78:E3:B5:12:97:D8', '78:E3:B5:12:97:D8',
                                    '78:E3:B5:12:97:D8', '78:E3:B5:12:97:D8',
                                    '78:E3:B5:12:97:D8', '78:E3:B5:12:97:D8'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '162643760',
                        IFLASTCHANGE => '(1080518709) 125 days, 1:26:27.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10115',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4044110657',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:0F',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '78:E3:B5:12:A7:0A', '78:E3:B5:12:A7:0A',
                                    '78:E3:B5:12:A7:0A', '78:E3:B5:12:A7:0A',
                                    '78:E3:B5:12:A7:0A', '78:E3:B5:12:A7:0A'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '178724675',
                        IFLASTCHANGE => '(1080518709) 125 days, 1:26:27.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10116',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2368363908',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:10',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:A5:AD:82', '00:24:81:A5:AD:82',
                                    '00:24:81:A5:AD:82', '00:24:81:A5:AD:82',
                                    '00:24:81:A5:AD:82', '00:24:81:A5:AD:82'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3269925864',
                        IFLASTCHANGE => '(1045238489) 120 days, 23:26:24.89',
                        IFMTU        => '1500',
                        IFNUMBER     => '10117',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3705223239',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:11',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:A5:8C:9A', '00:24:81:A5:8C:9A',
                                    '00:24:81:A5:8C:9A', '00:24:81:A5:8C:9A',
                                    '00:24:81:A5:8C:9A', '00:24:81:A5:8C:9A'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4294631',
                        IFLASTCHANGE => '(1045136906) 120 days, 23:09:29.06',
                        IFMTU        => '1500',
                        IFNUMBER     => '10118',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2364252031',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:12',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:A5:AD:84', '00:24:81:A5:AD:84',
                                    '00:24:81:A5:AD:84', '00:24:81:A5:AD:84',
                                    '00:24:81:A5:AD:84', '00:24:81:A5:AD:84'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2967336894',
                        IFLASTCHANGE => '(1045238529) 120 days, 23:26:25.29',
                        IFMTU        => '1500',
                        IFNUMBER     => '10119',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2335181126',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:13',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:24:81:A5:8C:99', '00:24:81:A5:8C:99',
                                    '00:24:81:A5:8C:99', '00:24:81:A5:8C:99',
                                    '00:24:81:A5:8C:99', '00:24:81:A5:8C:99'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '423040005',
                        IFLASTCHANGE => '(1045136858) 120 days, 23:09:28.58',
                        IFMTU        => '1500',
                        IFNUMBER     => '10120',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '585549480',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:14',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:A8:C8:A5', '00:15:60:A8:C8:A5',
                                    '00:15:60:A8:C8:A5', '00:15:60:A8:C8:A5',
                                    '00:15:60:A8:C8:A5', '00:15:60:A8:C8:A5'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3589075783',
                        IFLASTCHANGE => '(1045135806) 120 days, 23:09:18.06',
                        IFMTU        => '1500',
                        IFNUMBER     => '10121',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2388067209',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:15',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:A8:9A:32', '00:15:60:A8:9A:32',
                                    '00:15:60:A8:9A:32', '00:15:60:A8:9A:32',
                                    '00:15:60:A8:9A:32', '00:15:60:A8:9A:32'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2959412562',
                        IFLASTCHANGE => '(1045084012) 120 days, 23:00:40.12',
                        IFMTU        => '1500',
                        IFNUMBER     => '10122',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '203015691',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:16',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:A8:C8:A6', '00:15:60:A8:C8:A6',
                                    '00:15:60:A8:C8:A6', '00:15:60:A8:C8:A6',
                                    '00:15:60:A8:C8:A6', '00:15:60:A8:C8:A6'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/23',
                        IFINERRORS   => '1',
                        IFINOCTETS   => '3737853875',
                        IFLASTCHANGE => '(1045135682) 120 days, 23:09:16.82',
                        IFMTU        => '1500',
                        IFNUMBER     => '10123',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3740651309',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:17',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:15:60:A8:9A:31', '00:15:60:A8:9A:31',
                                    '00:15:60:A8:9A:31', '00:15:60:A8:9A:31',
                                    '00:15:60:A8:9A:31', '00:15:60:A8:9A:31'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2365558700',
                        IFLASTCHANGE => '(1045084138) 120 days, 23:00:41.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '10124',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2337013749',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:18',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'GigabitEthernet1/0/25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(9409) 0:01:34.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '10125',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '10000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:19',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '00:01:02:BF:F6:1F', '00:0A:5E:5F:54:86',
                                    '00:0A:5E:5F:54:AE', '00:0A:5E:5F:55:6A',
                                    '00:0A:5E:5F:55:AB', '00:0A:5E:5F:55:17',
                                    '00:10:5A:1B:C5:BE', '00:10:5A:09:8F:2A',
                                    '00:D0:B7:45:80:30', '00:18:F3:F0:0C:0E',
                                    '00:19:D1:82:AB:F6', '00:1B:2F:B3:C0:D5',
                                    '00:1C:C0:BD:D2:82', '00:1C:C0:BD:D6:F1',
                                    '00:1C:C0:BD:D7:6D', '00:1C:C0:BD:D7:79',
                                    '00:1C:C0:BD:D7:A2', '00:1C:C0:BD:D7:54',
                                    '00:1C:C0:BD:D8:E0', '00:1C:C0:BD:D9:1B',
                                    '00:1C:C0:BD:D9:3F', '00:1C:C0:DC:69:8F',
                                    '00:1C:C0:DC:69:92', '00:1C:C0:DC:69:23',
                                    '00:1C:C0:DC:6A:4F', '00:1C:C0:DC:6B:A0',
                                    '00:1C:C0:DC:6B:FA', '00:1C:C0:DC:6D:47',
                                    '00:1C:C0:DC:7A:B3', '00:1C:C0:DC:7A:EA',
                                    '00:1C:C0:DC:7B:17', '00:1C:C0:DC:7D:7F',
                                    '00:1C:C0:DF:37:09', '00:1C:C0:DF:39:B2',
                                    '00:1C:C0:DF:39:C2', '00:1C:C0:DF:39:EE',
                                    '00:1C:C0:DF:39:EF', '00:1C:C0:DF:39:F6',
                                    '00:1C:C0:DF:3A:88', '00:1C:C0:DF:3A:8A',
                                    '00:1C:C0:DF:3A:8B', '00:1C:C0:DF:3A:1F',
                                    '00:1C:C0:DF:3A:55', '00:1C:C0:DF:3A:5A',
                                    '00:03:22:01:9B:19', '00:27:0E:1E:B4:64',
                                    '00:27:0E:1E:B4:6D', '00:27:0E:1E:B4:72',
                                    '00:27:0E:1E:B4:73', '00:27:0E:1E:B4:7D',
                                    '00:27:0E:1E:B4:82', '00:27:0E:1E:B4:D1',
                                    '00:27:0E:1E:B4:DE', '00:27:0E:1E:B4:52',
                                    '00:27:0E:1E:B4:57', '00:27:0E:1E:B4:5C',
                                    '00:27:0E:2D:F8:64', '00:27:0E:2D:F9:60',
                                    '00:40:0D:8A:8B:47', '00:50:DA:D8:4E:47',
                                    '00:50:04:82:CE:89', '00:50:04:50:54:E8',
                                    '00:60:08:64:12:81', '00:60:08:64:15:F0',
                                    '00:60:08:64:16:8D', '00:60:08:64:16:05',
                                    '00:60:08:64:16:3F', '00:60:08:64:23:DD',
                                    '00:60:08:64:23:E5', '00:60:08:72:78:CB',
                                    '00:60:08:78:4C:52', '00:60:08:9F:35:75',
                                    '00:60:08:9F:35:83', '00:60:08:63:FA:63',
                                    '78:E7:D1:A9:3C:2B', '78:FE:3D:D5:0E:DB',
                                    'C8:9C:DC:F3:E7:71', 'C8:9C:DC:F4:EB:B0',
                                    'F8:0F:41:2C:43:7F', 'F8:0F:41:36:13:75',
                                    'F8:0F:41:36:46:93', 'F8:0F:41:36:47:A9',
                                    'F8:0F:41:36:47:E6', 'F8:0F:41:36:47:EB',
                                    'F8:0F:41:36:48:18', 'F8:0F:41:36:49:6B',
                                    'F8:0F:41:36:49:72', 'F8:0F:41:3B:13:6F',
                                    'F8:0F:41:3D:38:66', 'F8:0F:41:3D:38:A0',
                                    'F8:0F:41:3D:38:D7', 'F8:0F:41:3D:38:DA',
                                    'F8:0F:41:3D:38:26', 'F8:0F:41:3D:39:85',
                                    'F8:0F:41:3D:39:30', 'F8:0F:41:3D:39:35',
                                    'F8:0F:41:3D:43:64', 'F8:0F:41:3D:43:66',
                                    'F8:0F:41:3D:43:69', 'F8:0F:41:3D:43:8B',
                                    'F8:0F:41:3D:47:00', 'F8:0F:41:3D:48:95',
                                    'F8:0F:41:3D:48:C4', 'F8:0F:41:3D:48:CA',
                                    'F8:0F:41:3D:48:59', 'F8:0F:41:3E:0A:C9',
                                    'F8:0F:41:3E:0A:29', 'F8:0F:41:3E:0B:A8',
                                    'F8:0F:41:3E:0B:C5', 'F8:0F:41:3E:0B:D2',
                                    'F8:0F:41:3E:0C:BD', 'F8:0F:41:3E:0C:4E',
                                    'F8:0F:41:3E:07:37', 'F8:0F:41:3E:09:E6',
                                    'F8:0F:41:3E:09:2E', '20:CF:30:F0:82:D8',
                                    '20:CF:30:F0:82:E6', '00:01:02:BF:F6:1F',
                                    '00:0A:5E:5F:54:86', '00:0A:5E:5F:54:AE',
                                    '00:0A:5E:5F:55:6A', '00:0A:5E:5F:55:AB',
                                    '00:0A:5E:5F:55:17', '00:10:5A:1B:C5:BE',
                                    '00:10:5A:09:8F:2A', '00:D0:B7:45:80:30',
                                    '00:18:F3:F0:0C:0E', '00:19:D1:82:AB:F6',
                                    '00:1B:2F:B3:C0:D5', '00:1C:C0:BD:D2:82',
                                    '00:1C:C0:BD:D6:F1', '00:1C:C0:BD:D7:6D',
                                    '00:1C:C0:BD:D7:79', '00:1C:C0:BD:D7:A2',
                                    '00:1C:C0:BD:D7:54', '00:1C:C0:BD:D8:E0',
                                    '00:1C:C0:BD:D9:1B', '00:1C:C0:BD:D9:3F',
                                    '00:1C:C0:DC:69:8F', '00:1C:C0:DC:69:92',
                                    '00:1C:C0:DC:69:23', '00:1C:C0:DC:6A:4F',
                                    '00:1C:C0:DC:6B:A0', '00:1C:C0:DC:6B:FA',
                                    '00:1C:C0:DC:6D:47', '00:1C:C0:DC:7A:B3',
                                    '00:1C:C0:DC:7A:EA', '00:1C:C0:DC:7B:17',
                                    '00:1C:C0:DC:7D:7F', '00:1C:C0:DF:37:09',
                                    '00:1C:C0:DF:39:B2', '00:1C:C0:DF:39:C2',
                                    '00:1C:C0:DF:39:EE', '00:1C:C0:DF:39:EF',
                                    '00:1C:C0:DF:39:F6', '00:1C:C0:DF:3A:88',
                                    '00:1C:C0:DF:3A:8A', '00:1C:C0:DF:3A:8B',
                                    '00:1C:C0:DF:3A:1F', '00:1C:C0:DF:3A:55',
                                    '00:1C:C0:DF:3A:5A', '00:03:22:01:9B:19',
                                    '00:27:0E:1E:B4:64', '00:27:0E:1E:B4:6D',
                                    '00:27:0E:1E:B4:72', '00:27:0E:1E:B4:73',
                                    '00:27:0E:1E:B4:7D', '00:27:0E:1E:B4:82',
                                    '00:27:0E:1E:B4:D1', '00:27:0E:1E:B4:DE',
                                    '00:27:0E:1E:B4:52', '00:27:0E:1E:B4:57',
                                    '00:27:0E:1E:B4:5C', '00:27:0E:2D:F8:64',
                                    '00:27:0E:2D:F9:60', '00:40:0D:8A:8B:47',
                                    '00:50:DA:D8:4E:47', '00:50:04:82:CE:89',
                                    '00:50:04:50:54:E8', '00:60:08:64:12:81',
                                    '00:60:08:64:15:F0', '00:60:08:64:16:8D',
                                    '00:60:08:64:16:05', '00:60:08:64:16:3F',
                                    '00:60:08:64:23:DD', '00:60:08:64:23:E5',
                                    '00:60:08:72:78:CB', '00:60:08:78:4C:52',
                                    '00:60:08:9F:35:75', '00:60:08:9F:35:83',
                                    '00:60:08:63:FA:63', '78:E7:D1:A9:3C:2B',
                                    '78:FE:3D:D5:0E:DB', 'C8:9C:DC:F3:E7:71',
                                    'C8:9C:DC:F4:EB:B0', 'F8:0F:41:2C:43:7F',
                                    'F8:0F:41:36:13:75', 'F8:0F:41:36:46:93',
                                    'F8:0F:41:36:47:A9', 'F8:0F:41:36:47:E6',
                                    'F8:0F:41:36:47:EB', 'F8:0F:41:36:48:18',
                                    'F8:0F:41:36:49:6B', 'F8:0F:41:36:49:72',
                                    'F8:0F:41:3B:13:6F', 'F8:0F:41:3D:38:66',
                                    'F8:0F:41:3D:38:A0', 'F8:0F:41:3D:38:D7',
                                    'F8:0F:41:3D:38:DA', 'F8:0F:41:3D:38:26',
                                    'F8:0F:41:3D:39:85', 'F8:0F:41:3D:39:30',
                                    'F8:0F:41:3D:39:35', 'F8:0F:41:3D:43:64',
                                    'F8:0F:41:3D:43:66', 'F8:0F:41:3D:43:69',
                                    'F8:0F:41:3D:43:8B', 'F8:0F:41:3D:47:00',
                                    'F8:0F:41:3D:48:95', 'F8:0F:41:3D:48:C4',
                                    'F8:0F:41:3D:48:CA', 'F8:0F:41:3D:48:59',
                                    'F8:0F:41:3E:0A:C9', 'F8:0F:41:3E:0A:29',
                                    'F8:0F:41:3E:0B:A8', 'F8:0F:41:3E:0B:C5',
                                    'F8:0F:41:3E:0B:D2', 'F8:0F:41:3E:0C:BD',
                                    'F8:0F:41:3E:0C:4E', 'F8:0F:41:3E:07:37',
                                    'F8:0F:41:3E:09:E6', 'F8:0F:41:3E:09:2E',
                                    '20:CF:30:F0:82:D8', '20:CF:30:F0:82:E6',
                                    '00:01:02:BF:F6:1F', '00:0A:5E:5F:54:86',
                                    '00:0A:5E:5F:54:AE', '00:0A:5E:5F:55:6A',
                                    '00:0A:5E:5F:55:AB', '00:0A:5E:5F:55:17',
                                    '00:10:5A:1B:C5:BE', '00:10:5A:09:8F:2A',
                                    '00:D0:B7:45:80:30', '00:18:F3:F0:0C:0E',
                                    '00:19:D1:82:AB:F6', '00:1B:2F:B3:C0:D5',
                                    '00:1C:C0:BD:D2:82', '00:1C:C0:BD:D6:F1',
                                    '00:1C:C0:BD:D7:6D', '00:1C:C0:BD:D7:79',
                                    '00:1C:C0:BD:D7:A2', '00:1C:C0:BD:D7:54',
                                    '00:1C:C0:BD:D8:E0', '00:1C:C0:BD:D9:1B',
                                    '00:1C:C0:BD:D9:3F', '00:1C:C0:DC:69:8F',
                                    '00:1C:C0:DC:69:92', '00:1C:C0:DC:69:23',
                                    '00:1C:C0:DC:6A:4F', '00:1C:C0:DC:6B:A0',
                                    '00:1C:C0:DC:6B:FA', '00:1C:C0:DC:6D:47',
                                    '00:1C:C0:DC:7A:B3', '00:1C:C0:DC:7A:EA',
                                    '00:1C:C0:DC:7B:17', '00:1C:C0:DC:7D:7F',
                                    '00:1C:C0:DF:37:09', '00:1C:C0:DF:39:B2',
                                    '00:1C:C0:DF:39:C2', '00:1C:C0:DF:39:EE',
                                    '00:1C:C0:DF:39:EF', '00:1C:C0:DF:39:F6',
                                    '00:1C:C0:DF:3A:88', '00:1C:C0:DF:3A:8A',
                                    '00:1C:C0:DF:3A:8B', '00:1C:C0:DF:3A:1F',
                                    '00:1C:C0:DF:3A:55', '00:1C:C0:DF:3A:5A',
                                    '00:03:22:01:9B:19', '00:27:0E:1E:B4:64',
                                    '00:27:0E:1E:B4:6D', '00:27:0E:1E:B4:72',
                                    '00:27:0E:1E:B4:73', '00:27:0E:1E:B4:7D',
                                    '00:27:0E:1E:B4:82', '00:27:0E:1E:B4:D1',
                                    '00:27:0E:1E:B4:DE', '00:27:0E:1E:B4:52',
                                    '00:27:0E:1E:B4:57', '00:27:0E:1E:B4:5C',
                                    '00:27:0E:2D:F8:64', '00:27:0E:2D:F9:60',
                                    '00:40:0D:8A:8B:47', '00:50:DA:D8:4E:47',
                                    '00:50:04:82:CE:89', '00:50:04:50:54:E8',
                                    '00:60:08:64:12:81', '00:60:08:64:15:F0',
                                    '00:60:08:64:16:8D', '00:60:08:64:16:05',
                                    '00:60:08:64:16:3F', '00:60:08:64:23:DD',
                                    '00:60:08:64:23:E5', '00:60:08:72:78:CB',
                                    '00:60:08:78:4C:52', '00:60:08:9F:35:75',
                                    '00:60:08:9F:35:83', '00:60:08:63:FA:63',
                                    '78:E7:D1:A9:3C:2B', '78:FE:3D:D5:0E:DB',
                                    'C8:9C:DC:F3:E7:71', 'C8:9C:DC:F4:EB:B0',
                                    'F8:0F:41:2C:43:7F', 'F8:0F:41:36:13:75',
                                    'F8:0F:41:36:46:93', 'F8:0F:41:36:47:A9',
                                    'F8:0F:41:36:47:E6', 'F8:0F:41:36:47:EB',
                                    'F8:0F:41:36:48:18', 'F8:0F:41:36:49:6B',
                                    'F8:0F:41:36:49:72', 'F8:0F:41:3B:13:6F',
                                    'F8:0F:41:3D:38:66', 'F8:0F:41:3D:38:A0',
                                    'F8:0F:41:3D:38:D7', 'F8:0F:41:3D:38:DA',
                                    'F8:0F:41:3D:38:26', 'F8:0F:41:3D:39:85',
                                    'F8:0F:41:3D:39:30', 'F8:0F:41:3D:39:35',
                                    'F8:0F:41:3D:43:64', 'F8:0F:41:3D:43:66',
                                    'F8:0F:41:3D:43:69', 'F8:0F:41:3D:43:8B',
                                    'F8:0F:41:3D:47:00', 'F8:0F:41:3D:48:95',
                                    'F8:0F:41:3D:48:C4', 'F8:0F:41:3D:48:CA',
                                    'F8:0F:41:3D:48:59', 'F8:0F:41:3E:0A:C9',
                                    'F8:0F:41:3E:0A:29', 'F8:0F:41:3E:0B:A8',
                                    'F8:0F:41:3E:0B:C5', 'F8:0F:41:3E:0B:D2',
                                    'F8:0F:41:3E:0C:BD', 'F8:0F:41:3E:0C:4E',
                                    'F8:0F:41:3E:07:37', 'F8:0F:41:3E:09:E6',
                                    'F8:0F:41:3E:09:2E', '20:CF:30:F0:82:D8',
                                    '20:CF:30:F0:82:E6', '00:01:02:BF:F6:1F',
                                    '00:0A:5E:5F:54:86', '00:0A:5E:5F:54:AE',
                                    '00:0A:5E:5F:55:6A', '00:0A:5E:5F:55:AB',
                                    '00:0A:5E:5F:55:17', '00:10:5A:1B:C5:BE',
                                    '00:10:5A:09:8F:2A', '00:D0:B7:45:80:30',
                                    '00:18:F3:F0:0C:0E', '00:19:D1:82:AB:F6',
                                    '00:1B:2F:B3:C0:D5', '00:1C:C0:BD:D2:82',
                                    '00:1C:C0:BD:D6:F1', '00:1C:C0:BD:D7:6D',
                                    '00:1C:C0:BD:D7:79', '00:1C:C0:BD:D7:A2',
                                    '00:1C:C0:BD:D7:54', '00:1C:C0:BD:D8:E0',
                                    '00:1C:C0:BD:D9:1B', '00:1C:C0:BD:D9:3F',
                                    '00:1C:C0:DC:69:8F', '00:1C:C0:DC:69:92',
                                    '00:1C:C0:DC:69:23', '00:1C:C0:DC:6A:4F',
                                    '00:1C:C0:DC:6B:A0', '00:1C:C0:DC:6B:FA',
                                    '00:1C:C0:DC:6D:47', '00:1C:C0:DC:7A:B3',
                                    '00:1C:C0:DC:7A:EA', '00:1C:C0:DC:7B:17',
                                    '00:1C:C0:DC:7D:7F', '00:1C:C0:DF:37:09',
                                    '00:1C:C0:DF:39:B2', '00:1C:C0:DF:39:C2',
                                    '00:1C:C0:DF:39:EE', '00:1C:C0:DF:39:EF',
                                    '00:1C:C0:DF:39:F6', '00:1C:C0:DF:3A:88',
                                    '00:1C:C0:DF:3A:8A', '00:1C:C0:DF:3A:8B',
                                    '00:1C:C0:DF:3A:1F', '00:1C:C0:DF:3A:55',
                                    '00:1C:C0:DF:3A:5A', '00:03:22:01:9B:19',
                                    '00:27:0E:1E:B4:64', '00:27:0E:1E:B4:6D',
                                    '00:27:0E:1E:B4:72', '00:27:0E:1E:B4:73',
                                    '00:27:0E:1E:B4:7D', '00:27:0E:1E:B4:82',
                                    '00:27:0E:1E:B4:D1', '00:27:0E:1E:B4:DE',
                                    '00:27:0E:1E:B4:52', '00:27:0E:1E:B4:57',
                                    '00:27:0E:1E:B4:5C', '00:27:0E:2D:F8:64',
                                    '00:27:0E:2D:F9:60', '00:40:0D:8A:8B:47',
                                    '00:50:DA:D8:4E:47', '00:50:04:82:CE:89',
                                    '00:50:04:50:54:E8', '00:60:08:64:12:81',
                                    '00:60:08:64:15:F0', '00:60:08:64:16:8D',
                                    '00:60:08:64:16:05', '00:60:08:64:16:3F',
                                    '00:60:08:64:23:DD', '00:60:08:64:23:E5',
                                    '00:60:08:72:78:CB', '00:60:08:78:4C:52',
                                    '00:60:08:9F:35:75', '00:60:08:9F:35:83',
                                    '00:60:08:63:FA:63', '78:E7:D1:A9:3C:2B',
                                    '78:FE:3D:D5:0E:DB', 'C8:9C:DC:F3:E7:71',
                                    'C8:9C:DC:F4:EB:B0', 'F8:0F:41:2C:43:7F',
                                    'F8:0F:41:36:13:75', 'F8:0F:41:36:46:93',
                                    'F8:0F:41:36:47:A9', 'F8:0F:41:36:47:E6',
                                    'F8:0F:41:36:47:EB', 'F8:0F:41:36:48:18',
                                    'F8:0F:41:36:49:6B', 'F8:0F:41:36:49:72',
                                    'F8:0F:41:3B:13:6F', 'F8:0F:41:3D:38:66',
                                    'F8:0F:41:3D:38:A0', 'F8:0F:41:3D:38:D7',
                                    'F8:0F:41:3D:38:DA', 'F8:0F:41:3D:38:26',
                                    'F8:0F:41:3D:39:85', 'F8:0F:41:3D:39:30',
                                    'F8:0F:41:3D:39:35', 'F8:0F:41:3D:43:64',
                                    'F8:0F:41:3D:43:66', 'F8:0F:41:3D:43:69',
                                    'F8:0F:41:3D:43:8B', 'F8:0F:41:3D:47:00',
                                    'F8:0F:41:3D:48:95', 'F8:0F:41:3D:48:C4',
                                    'F8:0F:41:3D:48:CA', 'F8:0F:41:3D:48:59',
                                    'F8:0F:41:3E:0A:C9', 'F8:0F:41:3E:0A:29',
                                    'F8:0F:41:3E:0B:A8', 'F8:0F:41:3E:0B:C5',
                                    'F8:0F:41:3E:0B:D2', 'F8:0F:41:3E:0C:BD',
                                    'F8:0F:41:3E:0C:4E', 'F8:0F:41:3E:07:37',
                                    'F8:0F:41:3E:09:E6', 'F8:0F:41:3E:09:2E',
                                    '20:CF:30:F0:82:D8', '20:CF:30:F0:82:E6',
                                    '00:01:02:BF:F6:1F', '00:0A:5E:5F:54:86',
                                    '00:0A:5E:5F:54:AE', '00:0A:5E:5F:55:6A',
                                    '00:0A:5E:5F:55:AB', '00:0A:5E:5F:55:17',
                                    '00:10:5A:1B:C5:BE', '00:10:5A:09:8F:2A',
                                    '00:D0:B7:45:80:30', '00:18:F3:F0:0C:0E',
                                    '00:19:D1:82:AB:F6', '00:1B:2F:B3:C0:D5',
                                    '00:1C:C0:BD:D2:82', '00:1C:C0:BD:D6:F1',
                                    '00:1C:C0:BD:D7:6D', '00:1C:C0:BD:D7:79',
                                    '00:1C:C0:BD:D7:A2', '00:1C:C0:BD:D7:54',
                                    '00:1C:C0:BD:D8:E0', '00:1C:C0:BD:D9:1B',
                                    '00:1C:C0:BD:D9:3F', '00:1C:C0:DC:69:8F',
                                    '00:1C:C0:DC:69:92', '00:1C:C0:DC:69:23',
                                    '00:1C:C0:DC:6A:4F', '00:1C:C0:DC:6B:A0',
                                    '00:1C:C0:DC:6B:FA', '00:1C:C0:DC:6D:47',
                                    '00:1C:C0:DC:7A:B3', '00:1C:C0:DC:7A:EA',
                                    '00:1C:C0:DC:7B:17', '00:1C:C0:DC:7D:7F',
                                    '00:1C:C0:DF:37:09', '00:1C:C0:DF:39:B2',
                                    '00:1C:C0:DF:39:C2', '00:1C:C0:DF:39:EE',
                                    '00:1C:C0:DF:39:EF', '00:1C:C0:DF:39:F6',
                                    '00:1C:C0:DF:3A:88', '00:1C:C0:DF:3A:8A',
                                    '00:1C:C0:DF:3A:8B', '00:1C:C0:DF:3A:1F',
                                    '00:1C:C0:DF:3A:55', '00:1C:C0:DF:3A:5A',
                                    '00:03:22:01:9B:19', '00:27:0E:1E:B4:64',
                                    '00:27:0E:1E:B4:6D', '00:27:0E:1E:B4:72',
                                    '00:27:0E:1E:B4:73', '00:27:0E:1E:B4:7D',
                                    '00:27:0E:1E:B4:82', '00:27:0E:1E:B4:D1',
                                    '00:27:0E:1E:B4:DE', '00:27:0E:1E:B4:52',
                                    '00:27:0E:1E:B4:57', '00:27:0E:1E:B4:5C',
                                    '00:27:0E:2D:F8:64', '00:27:0E:2D:F9:60',
                                    '00:40:0D:8A:8B:47', '00:50:DA:D8:4E:47',
                                    '00:50:04:82:CE:89', '00:50:04:50:54:E8',
                                    '00:60:08:64:12:81', '00:60:08:64:15:F0',
                                    '00:60:08:64:16:8D', '00:60:08:64:16:05',
                                    '00:60:08:64:16:3F', '00:60:08:64:23:DD',
                                    '00:60:08:64:23:E5', '00:60:08:72:78:CB',
                                    '00:60:08:78:4C:52', '00:60:08:9F:35:75',
                                    '00:60:08:9F:35:83', '00:60:08:63:FA:63',
                                    '78:E7:D1:A9:3C:2B', '78:FE:3D:D5:0E:DB',
                                    'C8:9C:DC:F3:E7:71', 'C8:9C:DC:F4:EB:B0',
                                    'F8:0F:41:2C:43:7F', 'F8:0F:41:36:13:75',
                                    'F8:0F:41:36:46:93', 'F8:0F:41:36:47:A9',
                                    'F8:0F:41:36:47:E6', 'F8:0F:41:36:47:EB',
                                    'F8:0F:41:36:48:18', 'F8:0F:41:36:49:6B',
                                    'F8:0F:41:36:49:72', 'F8:0F:41:3B:13:6F',
                                    'F8:0F:41:3D:38:66', 'F8:0F:41:3D:38:A0',
                                    'F8:0F:41:3D:38:D7', 'F8:0F:41:3D:38:DA',
                                    'F8:0F:41:3D:38:26', 'F8:0F:41:3D:39:85',
                                    'F8:0F:41:3D:39:30', 'F8:0F:41:3D:39:35',
                                    'F8:0F:41:3D:43:64', 'F8:0F:41:3D:43:66',
                                    'F8:0F:41:3D:43:69', 'F8:0F:41:3D:43:8B',
                                    'F8:0F:41:3D:47:00', 'F8:0F:41:3D:48:95',
                                    'F8:0F:41:3D:48:C4', 'F8:0F:41:3D:48:CA',
                                    'F8:0F:41:3D:48:59', 'F8:0F:41:3E:0A:C9',
                                    'F8:0F:41:3E:0A:29', 'F8:0F:41:3E:0B:A8',
                                    'F8:0F:41:3E:0B:C5', 'F8:0F:41:3E:0B:D2',
                                    'F8:0F:41:3E:0C:BD', 'F8:0F:41:3E:0C:4E',
                                    'F8:0F:41:3E:07:37', 'F8:0F:41:3E:09:E6',
                                    'F8:0F:41:3E:09:2E', '20:CF:30:F0:82:D8',
                                    '20:CF:30:F0:82:E6', '00:01:02:BF:F6:1F',
                                    '00:0A:5E:5F:54:86', '00:0A:5E:5F:54:AE',
                                    '00:0A:5E:5F:55:6A', '00:0A:5E:5F:55:AB',
                                    '00:0A:5E:5F:55:17', '00:10:5A:1B:C5:BE',
                                    '00:10:5A:09:8F:2A', '00:D0:B7:45:80:30',
                                    '00:18:F3:F0:0C:0E', '00:19:D1:82:AB:F6',
                                    '00:1B:2F:B3:C0:D5', '00:1C:C0:BD:D2:82',
                                    '00:1C:C0:BD:D6:F1', '00:1C:C0:BD:D7:6D',
                                    '00:1C:C0:BD:D7:79', '00:1C:C0:BD:D7:A2',
                                    '00:1C:C0:BD:D7:54', '00:1C:C0:BD:D8:E0',
                                    '00:1C:C0:BD:D9:1B', '00:1C:C0:BD:D9:3F',
                                    '00:1C:C0:DC:69:8F', '00:1C:C0:DC:69:92',
                                    '00:1C:C0:DC:69:23', '00:1C:C0:DC:6A:4F',
                                    '00:1C:C0:DC:6B:A0', '00:1C:C0:DC:6B:FA',
                                    '00:1C:C0:DC:6D:47', '00:1C:C0:DC:7A:B3',
                                    '00:1C:C0:DC:7A:EA', '00:1C:C0:DC:7B:17',
                                    '00:1C:C0:DC:7D:7F', '00:1C:C0:DF:37:09',
                                    '00:1C:C0:DF:39:B2', '00:1C:C0:DF:39:C2',
                                    '00:1C:C0:DF:39:EE', '00:1C:C0:DF:39:EF',
                                    '00:1C:C0:DF:39:F6', '00:1C:C0:DF:3A:88',
                                    '00:1C:C0:DF:3A:8A', '00:1C:C0:DF:3A:8B',
                                    '00:1C:C0:DF:3A:1F', '00:1C:C0:DF:3A:55',
                                    '00:1C:C0:DF:3A:5A', '00:03:22:01:9B:19',
                                    '00:27:0E:1E:B4:64', '00:27:0E:1E:B4:6D',
                                    '00:27:0E:1E:B4:72', '00:27:0E:1E:B4:73',
                                    '00:27:0E:1E:B4:7D', '00:27:0E:1E:B4:82',
                                    '00:27:0E:1E:B4:D1', '00:27:0E:1E:B4:DE',
                                    '00:27:0E:1E:B4:52', '00:27:0E:1E:B4:57',
                                    '00:27:0E:1E:B4:5C', '00:27:0E:2D:F8:64',
                                    '00:27:0E:2D:F9:60', '00:40:0D:8A:8B:47',
                                    '00:50:DA:D8:4E:47', '00:50:04:82:CE:89',
                                    '00:50:04:50:54:E8', '00:60:08:64:12:81',
                                    '00:60:08:64:15:F0', '00:60:08:64:16:8D',
                                    '00:60:08:64:16:05', '00:60:08:64:16:3F',
                                    '00:60:08:64:23:DD', '00:60:08:64:23:E5',
                                    '00:60:08:72:78:CB', '00:60:08:78:4C:52',
                                    '00:60:08:9F:35:75', '00:60:08:9F:35:83',
                                    '00:60:08:63:FA:63', '78:E7:D1:A9:3C:2B',
                                    '78:FE:3D:D5:0E:DB', 'C8:9C:DC:F3:E7:71',
                                    'C8:9C:DC:F4:EB:B0', 'F8:0F:41:2C:43:7F',
                                    'F8:0F:41:36:13:75', 'F8:0F:41:36:46:93',
                                    'F8:0F:41:36:47:A9', 'F8:0F:41:36:47:E6',
                                    'F8:0F:41:36:47:EB', 'F8:0F:41:36:48:18',
                                    'F8:0F:41:36:49:6B', 'F8:0F:41:36:49:72',
                                    'F8:0F:41:3B:13:6F', 'F8:0F:41:3D:38:66',
                                    'F8:0F:41:3D:38:A0', 'F8:0F:41:3D:38:D7',
                                    'F8:0F:41:3D:38:DA', 'F8:0F:41:3D:38:26',
                                    'F8:0F:41:3D:39:85', 'F8:0F:41:3D:39:30',
                                    'F8:0F:41:3D:39:35', 'F8:0F:41:3D:43:64',
                                    'F8:0F:41:3D:43:66', 'F8:0F:41:3D:43:69',
                                    'F8:0F:41:3D:43:8B', 'F8:0F:41:3D:47:00',
                                    'F8:0F:41:3D:48:95', 'F8:0F:41:3D:48:C4',
                                    'F8:0F:41:3D:48:CA', 'F8:0F:41:3D:48:59',
                                    'F8:0F:41:3E:0A:C9', 'F8:0F:41:3E:0A:29',
                                    'F8:0F:41:3E:0B:A8', 'F8:0F:41:3E:0B:C5',
                                    'F8:0F:41:3E:0B:D2', 'F8:0F:41:3E:0C:BD',
                                    'F8:0F:41:3E:0C:4E', 'F8:0F:41:3E:07:37',
                                    'F8:0F:41:3E:09:E6', 'F8:0F:41:3E:09:2E',
                                    '20:CF:30:F0:82:D8', '20:CF:30:F0:82:E6'
                                ]
                            }
                        },
                        IFDESCR      => 'GigabitEthernet1/0/26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '381223375',
                        IFLASTCHANGE => '(1148414732) 132 days, 22:02:27.32',
                        IFMTU        => '1500',
                        IFNUMBER     => '10126',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3173019806',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:1A',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'TenGigabitEthernet1/0/1',
                                IP      => '192.168.1.150',
                                MODEL   => 'cisco WS-C2960S-24TD-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'SALSERV-INTERUFR-150.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'TenGigabitEthernet1/0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2403147337',
                        IFLASTCHANGE => '(12761) 0:02:07.61',
                        IFMTU        => '1500',
                        IFNUMBER     => '10201',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '861764751',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:1B',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'TenGigabitEthernet1/0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(11779) 0:01:57.79',
                        IFMTU        => '1500',
                        IFNUMBER     => '10202',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:1C',
                        VLANS        => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '12001',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet1/0/3',
                                IP      => '192.168.1.160',
                                MODEL   => 'cisco WS-C2960S-24TD-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'SALSERV-160.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'FastEthernet0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1978888964',
                        IFLASTCHANGE => '(11520) 0:01:55.20',
                        IFMTU        => '1500',
                        IFNUMBER     => '12002',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1282126124',
                        IFSPEED      => '100000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '18:33:9D:E7:15:39'
                    }
                ]
            }
        }
    ],
    'cisco/C2960S.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-202.mgmt.dauphine.fr',
            MAC          => 'B4:14:89:38:2D:80',
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
            SNMPHOSTNAME => 'CB-C005-202.mgmt.dauphine.fr',
            MAC          => 'B4:14:89:38:2D:80',
            MODELSNMP    => 'Networking2147',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'FOC1440Z0HG'
        },
        {
            INFO => {
                COMMENTS => 'Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)
Technical Support: http://www.cisco.com/techsupport
Copyright (c) 1986-2011 by Cisco Systems, Inc.
Compiled Thu 05-May-11 03:03 by prod_rel_team',
                FIRMWARE => '12.2(58)SE1',
                ID       => undef,
                IPS      => {
                    IP => [ '192.168.1.202' ]
                },
                MAC          => 'B4:14:89:38:2D:80',
                MANUFACTURER => 'Cisco',
                MEMORY       => 33,
                MODEL        => 'WS-C2960S-24TD-L',
                NAME         => 'CB-C005-202.mgmt.dauphine.fr',
                RAM          => 128,
                SERIAL       => 'FOC1440Z0HG',
                TYPE         => 'NETWORKING',
                UPTIME       => '(1038728684) 120 days, 5:21:26.84'
            },
            PORTS => {
                PORT => [
                    {
                        IFDESCR          => 'Vlan1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1809150271',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17290) 0:02:52.90',
                        IFMTU            => '1500',
                        IFNAME           => 'Vl1',
                        IFNUMBER         => '1',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1363105400',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'propVirtual(53)',
                        MAC              => 'B4:14:89:38:2D:C0'
                    },
                    {
                        IFDESCR          => 'StackPort1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16110) 0:02:41.10',
                        IFMTU            => '0',
                        IFNAME           => 'StackPort1',
                        IFNUMBER         => '5137',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '0',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'StackSub-St1-1',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFNAME           => 'StackSub-St1-1',
                        IFNUMBER         => '5138',
                        IFSPEED          => '0',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'StackSub-St1-2',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFNAME           => 'StackSub-St1-2',
                        IFNUMBER         => '5139',
                        IFSPEED          => '0',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'propVirtual(53)'
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16998) 0:02:49.98',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/1',
                        IFNUMBER         => '10101',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:81',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/2',
                        IFNUMBER         => '10102',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:82',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/3',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/3',
                        IFNUMBER         => '10103',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:83',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/4',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/4',
                        IFNUMBER         => '10104',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:84',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan25',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/5',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/5',
                        IFNUMBER         => '10105',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:85',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan25',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/6',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/6',
                        IFNUMBER         => '10106',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:86',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan25',
                                    NUMBER => '30'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/7',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/7',
                        IFNUMBER         => '10107',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:87',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan50',
                                    NUMBER => '55'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/8',
                        IFINERRORS       => '7',
                        IFINOCTETS       => '2000020446',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(1035006831) 119 days, 19:01:08.31',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/8',
                        IFNUMBER         => '10108',
                        IFOUTERRORS      => '10196',
                        IFOUTOCTETS      => '3785939163',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:88',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/9',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/9',
                        IFNUMBER         => '10109',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:89',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/10',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16999) 0:02:49.99',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/10',
                        IFNUMBER         => '10110',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:8A',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/11',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/11',
                        IFNUMBER         => '10111',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:8B',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan50',
                                    NUMBER => '55'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/12',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/12',
                        IFNUMBER         => '10112',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:8C',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/13',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/13',
                        IFNUMBER         => '10113',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:8D',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/14',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/14',
                        IFNUMBER         => '10114',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:8E',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/15',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/15',
                        IFNUMBER         => '10115',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:8F',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/16',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/16',
                        IFNUMBER         => '10116',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:90',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'vlan2',
                                    NUMBER => '7'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/17',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1875470774',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(412923121) 47 days, 19:00:31.21',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/17',
                        IFNUMBER         => '10117',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '616408260',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:91'
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/18',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17000) 0:02:50.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/18',
                        IFNUMBER         => '10118',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:92'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0',
                                IP      => '192.168.55.47',
                                MODEL   => 'cisco AIR-AP1142N-E-K9    ',
                                SYSDESCR =>
        '"Cisco IOS Software, C1140 Software (C1140-K9W7-M), Version 12.4(21a)JA1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'wifi-P416-47.wifi-mngt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/19',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '239963405',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17347) 0:02:53.47',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/19',
                        IFNUMBER         => '10119',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '481681887',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:93'
                    },
                    {
                        CONNECTIONS => {
                            CONNECTION => {
                                MAC => [
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8',
                                    '64:87:88:B0:39:C1', '64:87:88:B0:3A:81',
                                    '64:87:88:B0:44:81', 'E8:E7:32:4B:7B:B4',
                                    'E8:E7:32:4B:86:DB', 'E8:E7:32:4B:8A:CC',
                                    'E8:E7:32:4B:9B:D8', '64:87:88:B0:39:C1',
                                    '64:87:88:B0:3A:81', '64:87:88:B0:44:81',
                                    'E8:E7:32:4B:7B:B4', 'E8:E7:32:4B:86:DB',
                                    'E8:E7:32:4B:8A:CC', 'E8:E7:32:4B:9B:D8'
                                ]
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/20',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '456792940',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/20',
                        IFNUMBER         => '10120',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2470821375',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:94'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.207',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-C005-207.Dauphine'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/21',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '344390677',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17651) 0:02:56.51',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/21',
                        IFNUMBER         => '10121',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2696731730',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:95'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.206',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-C005-206.Dauphine'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/22',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '3638606372',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/22',
                        IFNUMBER         => '10122',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2995779946',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:96'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.208',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-C005-208.Dauphine'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/23',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1930398362',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/23',
                        IFNUMBER         => '10123',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '2602167926',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:97'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.205',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 15.0(1)SE3, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-C005-205.Dauphine'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/24',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1156483157',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17348) 0:02:53.48',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/24',
                        IFNUMBER         => '10124',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '1997977582',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:98'
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.217',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB-DIVERS-217.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR          => 'GigabitEthernet1/0/25',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '1598430128',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(18797) 0:03:07.97',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/25',
                        IFNUMBER         => '10125',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '4219364696',
                        IFSPEED          => '1000000000',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:99'
                    },
                    {
                        IFDESCR          => 'GigabitEthernet1/0/26',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(16113) 0:02:41.13',
                        IFMTU            => '1500',
                        IFNAME           => 'Gi1/0/26',
                        IFNUMBER         => '10126',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '10000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:9A'
                    },
                    {
                        IFDESCR          => 'TenGigabitEthernet1/0/1',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(18496) 0:03:04.96',
                        IFMTU            => '1500',
                        IFNAME           => 'Te1/0/1',
                        IFNUMBER         => '10201',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:9B',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'TenGigabitEthernet1/0/2',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(17001) 0:02:50.01',
                        IFMTU            => '1500',
                        IFNAME           => 'Te1/0/2',
                        IFNUMBER         => '10202',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:9C',
                        VLANS            => {
                            VLAN => [
                                {
                                    NAME   => 'FastEthernet0',
                                    NUMBER => '1'
                                }
                            ]
                        }
                    },
                    {
                        IFDESCR          => 'Null0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'up(1)',
                        IFLASTCHANGE     => '(0) 0:00:00.00',
                        IFMTU            => '1500',
                        IFNAME           => 'Nu0',
                        IFNUMBER         => '12001',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '4294967295',
                        IFSTATUS         => 'up(1)',
                        IFTYPE           => 'other(1)'
                    },
                    {
                        IFDESCR          => 'FastEthernet0',
                        IFINERRORS       => '0',
                        IFINOCTETS       => '0',
                        IFINTERNALSTATUS => 'down(2)',
                        IFLASTCHANGE     => '(16930) 0:02:49.30',
                        IFMTU            => '1500',
                        IFNAME           => 'Fa0',
                        IFNUMBER         => '12002',
                        IFOUTERRORS      => '0',
                        IFOUTOCTETS      => '0',
                        IFSPEED          => '100000000',
                        IFSTATUS         => 'down(2)',
                        IFTYPE           => 'ethernetCsmacd(6)',
                        MAC              => 'B4:14:89:38:2D:B9'
                    }
                ]
            }
        }
    ],
    'cisco/C3550.1.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.mgmt.dauphine.fr',
            MAC          => '00:0B:5F:CC:D8:80'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.mgmt.dauphine.fr',
            MAC          => '00:0B:5F:CC:D8:80',
            MODELSNMP    => 'Networking2034',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'CAT0647X118',
        },
        {
            INFO => {
                COMMENTS => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
                CPU          => '97',
                FIRMWARE     => 'CW_VERSION$12.1(20)EA1a$',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 42,
                MODEL        => 'WS-C3550-12G',
                NAME         => 'CB-Federateur.mgmt.dauphine.fr',
                RAM          => 63,
                SERIAL       => 'CAT0647X118',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.201',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB-Switch-201.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '180537907',
                        IFLASTCHANGE => '(484116314) 56 days, 0:46:03.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1011556546',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:81',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3867512040',
                        IFLASTCHANGE => '(2549311166) 295 days, 1:25:11.66',
                        IFMTU        => '1500',
                        IFNUMBER     => '2',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '290573111',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:82',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.51',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AP-Switch-51.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4201293261',
                        IFLASTCHANGE => '(3567778147) 412 days, 22:29:41.47',
                        IFMTU        => '1500',
                        IFNUMBER     => '3',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '943956504',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:83',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.101',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CP-Switch-101.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3886274843',
                        IFLASTCHANGE => '(3092449227) 357 days, 22:08:12.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '4',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3120044741',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:84',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/2',
                                IP      => '192.168.1.221',
                                MODEL   => 'cisco WS-C3560-24PS',
                                SYSDESCR =>
        '"Cisco IOS Software, C3560 Software (C3560-IPBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB6-BU-221.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2830133767',
                        IFLASTCHANGE => '(2512038666) 290 days, 17:53:06.66',
                        IFMTU        => '1500',
                        IFNUMBER     => '5',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4249428806',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:85',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.218',
                                MODEL   => 'cisco WS-C2960-24TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB-C125-218.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1115997810',
                        IFLASTCHANGE => '(2156630557) 249 days, 14:38:25.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '6',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1893127079',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:86',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet1/0/25',
                                IP      => '192.168.1.160',
                                MODEL   => 'cisco WS-C2960S-24TD-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'SALSERV-160.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3445477068',
                        IFLASTCHANGE => '(2549322052) 295 days, 1:27:00.52',
                        IFMTU        => '1500',
                        IFNUMBER     => '7',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '574739419',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:87',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/2',
                                IP      => '192.168.1.152',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE2, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'SALSERV-152.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2984968729',
                        IFLASTCHANGE => '(2549310972) 295 days, 1:25:09.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '8',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '561349813',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:88',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.1',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AB-Switch-1.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '588728158',
                        IFLASTCHANGE => '(3568000911) 412 days, 23:06:49.11',
                        IFMTU        => '1500',
                        IFNUMBER     => '9',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1525029225',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:89',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '98138483',
                        IFLASTCHANGE => '(2392354398) 276 days, 21:25:43.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2340502692',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:8A',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '4141947452',
                        IFLASTCHANGE => '(4164697427) 482 days, 0:36:14.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '11',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '4106000860',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:8B',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.27',
                                MODEL   => 'cisco WS-C2960-24TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-27.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1426737530',
                        IFLASTCHANGE => '(476695464) 55 days, 4:09:14.64',
                        IFMTU        => '1500',
                        IFNUMBER     => '12',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1037515211',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:8C',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '13',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    },
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1525083978',
                        IFLASTCHANGE => '(9438) 0:01:34.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '14',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3784751394',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2925658248',
                        IFLASTCHANGE => '(9438) 0:01:34.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '15',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '921408266',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '308107072',
                        IFLASTCHANGE => '(2359259786) 273 days, 1:29:57.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '16',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3275196',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1300929099',
                        IFLASTCHANGE => '(9438) 0:01:34.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '17',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '461030167',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3666146863',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '18',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '293335971',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '731125063',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '19',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '727637538',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3589275562',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '20',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1996045557',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '21',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '201358471',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '24800747',
                        IFLASTCHANGE => '(906522342) 104 days, 22:07:03.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '22',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '69531603',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '969764756',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '23',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '505094134',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '912202175',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '24',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '406405478',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '18107654',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '25',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '22156322',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2935779928',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '26',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '554925716',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1262482289',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '27',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '156743587',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '285431783',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '28',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '204443724',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3270804562',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '29',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '151588827',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2697229546',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '30',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1552869729',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '714313794',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '31',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '315908357',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2789987500',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '32',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '82700994',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3486144',
                        IFLASTCHANGE => '(6726) 0:01:07.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '33',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2343680',
                        IFLASTCHANGE => '(837346286) 96 days, 21:57:42.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '34',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '17687616',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1844712773',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '35',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1164425501',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1283464573',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '36',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '346380743',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '26920726',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '37',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '36318863',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3064833469',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '38',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1918653057',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '338752885',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '39',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '448530768',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2992067052',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '40',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '109842849',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2439400107',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '41',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '953579070',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2687627494',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '42',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '85231534',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '812488624',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '43',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1354851503',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '72258689',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '44',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '211309587',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '397017901',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '45',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2116392197',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1418291283',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '46',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '48133885',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '994774647',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '47',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '159813169',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '444116144',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '48',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '343719204',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '26090918',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '49',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '26386466',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1159745060',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '50',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '635832012',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1012869239',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '51',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1105831805',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '483228390',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '52',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1086401212',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1372343872',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '53',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '53271806',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '54',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3788625476',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '55',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '788748238',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '175265926',
                        IFLASTCHANGE => '(12414) 0:02:04.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '56',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '12227352',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '84633088',
                        IFLASTCHANGE => '(6809) 0:01:08.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '57',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '13189',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '58',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '14842536',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '629694788',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '59',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '551119289',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '169895626',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '60',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '12975579',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '23318539',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '61',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '35099834',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan49',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3910338505',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '62',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '717521964',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan51',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2179932368',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '64',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1827534135',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan52',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '758660474',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '65',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1424172185',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan53',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1288973768',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '66',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '849506917',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan54',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '373855909',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '67',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '109926504',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan55',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '51239906',
                        IFLASTCHANGE => '(3092517394) 357 days, 22:19:33.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '68',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '32529615',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan56',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1483788292',
                        IFLASTCHANGE => '(1823189271) 211 days, 0:24:52.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '69',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1282343630',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan57',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '204459822',
                        IFLASTCHANGE => '(12415) 0:02:04.15',
                        IFMTU        => '1500',
                        IFNUMBER     => '70',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '164584478',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan99',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '49771490',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '74',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '49456970',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan58',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '836890474',
                        IFLASTCHANGE => '(1980745831) 229 days, 6:04:18.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '75',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '40488',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan60',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '108352',
                        IFLASTCHANGE => '(1565251543) 181 days, 3:55:15.43',
                        IFMTU        => '1500',
                        IFNUMBER     => '77',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan63',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '890729714',
                        IFLASTCHANGE => '(3300554327) 382 days, 0:12:23.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '79',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '354728196',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan64',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(3791708590) 438 days, 20:31:25.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '80',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '30300',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    }
                ]
            }
        }
    ],
    'cisco/C3550.2.walk' => [
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.mgmt.dauphine.fr',
            MAC          => '00:0B:5F:CC:D8:80'
        },
        {
            MANUFACTURER => 'Cisco',
            TYPE         => 'NETWORKING',
            DESCRIPTION  => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
            SNMPHOSTNAME => 'CB-Federateur.mgmt.dauphine.fr',
            MAC          => '00:0B:5F:CC:D8:80',
            MODELSNMP    => 'Networking2034',
            MODEL        => undef,
            FIRMWARE     => undef,
            SERIAL       => 'CAT0647X118',
        },
        {
            INFO => {
                COMMENTS => 'Cisco Internetwork Operating System Software 
IOS (tm) C3550 Software (C3550-I5Q3L2-M), Version 12.1(20)EA1a, RELEASE SOFTWARE (fc1)
Copyright (c) 1986-2004 by cisco Systems, Inc.
Compiled Mon 19-Apr-04 21:50 by yenanh',
                CPU          => '97',
                FIRMWARE     => 'CW_VERSION$12.1(20)EA1a$',
                ID           => undef,
                MANUFACTURER => 'Cisco',
                MEMORY       => 42,
                MODEL        => 'WS-C3550-12G',
                NAME         => 'CB-Federateur.mgmt.dauphine.fr',
                RAM          => 63,
                SERIAL       => 'CAT0647X118',
                TYPE         => 'NETWORKING'
            },
            PORTS => {
                PORT => [
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.201',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB-Switch-201.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '45816609',
                        IFLASTCHANGE => '(484116314) 56 days, 0:46:03.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '1',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '411569365',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:81',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3858273141',
                        IFLASTCHANGE => '(2549311166) 295 days, 1:25:11.66',
                        IFMTU        => '1500',
                        IFNUMBER     => '2',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '281217309',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:82',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.51',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AP-Switch-51.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '622220740',
                        IFLASTCHANGE => '(3567778147) 412 days, 22:29:41.47',
                        IFMTU        => '1500',
                        IFNUMBER     => '3',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '538499752',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:83',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.101',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CP-Switch-101.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3510726368',
                        IFLASTCHANGE => '(3092449227) 357 days, 22:08:12.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '4',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2683827189',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:84',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/2',
                                IP      => '192.168.1.221',
                                MODEL   => 'cisco WS-C3560-24PS',
                                SYSDESCR =>
        '"Cisco IOS Software, C3560 Software (C3560-IPBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB6-BU-221.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2774799775',
                        IFLASTCHANGE => '(2512038666) 290 days, 17:53:06.66',
                        IFMTU        => '1500',
                        IFNUMBER     => '5',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2915510749',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:85',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.218',
                                MODEL   => 'cisco WS-C2960-24TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'CB-C125-218.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1115388661',
                        IFLASTCHANGE => '(2156630557) 249 days, 14:38:25.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '6',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1885777963',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:86',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet1/0/25',
                                IP      => '192.168.1.160',
                                MODEL   => 'cisco WS-C2960S-24TD-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960S Software (C2960S-UNIVERSALK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'SALSERV-160.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '467916358',
                        IFLASTCHANGE => '(2549322052) 295 days, 1:27:00.52',
                        IFMTU        => '1500',
                        IFNUMBER     => '7',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3565993718',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:87',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/2',
                                IP      => '192.168.1.152',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(25)SEE2, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'SALSERV-152.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2977706573',
                        IFLASTCHANGE => '(2549310972) 295 days, 1:25:09.72',
                        IFMTU        => '1500',
                        IFNUMBER     => '8',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '552271083',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:88',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.1',
                                MODEL   => 'cisco WS-C2960-48TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASE-M), Version 12.2(46)SE, RELEASE SOFTWARE (fc2)',
                                SYSNAME => 'AB-Switch-1.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '108504863',
                        IFLASTCHANGE => '(3568000911) 412 days, 23:06:49.11',
                        IFMTU        => '1500',
                        IFNUMBER     => '9',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '664679833',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:89',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '98137127',
                        IFLASTCHANGE => '(2392354398) 276 days, 21:25:43.98',
                        IFMTU        => '1500',
                        IFNUMBER     => '10',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2340388452',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:8A',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'GigabitEthernet0/11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1710916739',
                        IFLASTCHANGE => '(4164697427) 482 days, 0:36:14.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '11',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3176277119',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:8B',
                        TRUNK        => 1
                    },
                    {
                        CONNECTIONS => {
                            CDP        => 1,
                            CONNECTION => {
                                IFDESCR => 'GigabitEthernet0/1',
                                IP      => '192.168.1.27',
                                MODEL   => 'cisco WS-C2960-24TC-L',
                                SYSDESCR =>
        '"Cisco IOS Software, C2960 Software (C2960-LANBASEK9-M), Version 12.2(58)SE1, RELEASE SOFTWARE (fc1)',
                                SYSNAME => 'CB-27.mgmt.dauphine.fr'
                            }
                        },
                        IFDESCR      => 'GigabitEthernet0/12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1402074638',
                        IFLASTCHANGE => '(476695464) 55 days, 4:09:14.64',
                        IFMTU        => '1500',
                        IFNUMBER     => '12',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1004750980',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'ethernetCsmacd(6)',
                        MAC          => '00:0B:5F:CC:D8:8C',
                        TRUNK        => 1
                    },
                    {
                        IFDESCR      => 'Null0',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(0) 0:00:00.00',
                        IFMTU        => '1500',
                        IFNUMBER     => '13',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '4294967295',
                        IFTYPE       => 'other(1)'
                    },
                    {
                        IFDESCR      => 'Vlan1',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1524951264',
                        IFLASTCHANGE => '(9438) 0:01:34.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '14',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3784205374',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan2',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2925654574',
                        IFLASTCHANGE => '(9438) 0:01:34.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '15',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '921361583',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan3',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '308095168',
                        IFLASTCHANGE => '(2359259786) 273 days, 1:29:57.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '16',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '3275196',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan4',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1300841453',
                        IFLASTCHANGE => '(9438) 0:01:34.38',
                        IFMTU        => '1500',
                        IFNUMBER     => '17',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '461023207',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan5',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3665968605',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '18',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '293334951',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan6',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '731097984',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '19',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '727629138',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan7',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3588580968',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '20',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan8',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1995879669',
                        IFLASTCHANGE => '(9440) 0:01:34.40',
                        IFMTU        => '1500',
                        IFNUMBER     => '21',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '201355359',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan9',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '24796203',
                        IFLASTCHANGE => '(906522342) 104 days, 22:07:03.42',
                        IFMTU        => '1500',
                        IFNUMBER     => '22',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '69531423',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan10',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '969754878',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '23',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '505089052',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan11',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '912171837',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '24',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '406399358',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan12',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '18107654',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '25',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '22156322',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan13',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2935774824',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '26',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '554925596',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan14',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1262480508',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '27',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '156743227',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan15',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '285430619',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '28',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '204442164',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan16',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3270744749',
                        IFLASTCHANGE => '(9445) 0:01:34.45',
                        IFMTU        => '1500',
                        IFNUMBER     => '29',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '151574275',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan17',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2697199273',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '30',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1552861989',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan18',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '714290691',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '31',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '315901869',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan19',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2789966222',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '32',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '82699614',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan20',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3486144',
                        IFLASTCHANGE => '(6726) 0:01:07.26',
                        IFMTU        => '1500',
                        IFNUMBER     => '33',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan21',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2343616',
                        IFLASTCHANGE => '(837346286) 96 days, 21:57:42.86',
                        IFMTU        => '1500',
                        IFNUMBER     => '34',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '17687616',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan22',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1844682199',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '35',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1164417941',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan23',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1283399497',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '36',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '346379183',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan24',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '26909654',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '37',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '36318443',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan25',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3064803582',
                        IFLASTCHANGE => '(9446) 0:01:34.46',
                        IFMTU        => '1500',
                        IFNUMBER     => '38',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1918629277',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan26',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '338750811',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '39',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '448529958',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan27',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2992035941',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '40',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '109841469',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan28',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2439367484',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '41',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '953575220',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan29',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2687600589',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '42',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '85230814',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan30',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '812404160',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '43',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1354835843',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan31',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '72258689',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '44',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '211308147',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan32',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '384143318',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '45',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '2103712769',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan33',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1418227791',
                        IFLASTCHANGE => '(9448) 0:01:34.48',
                        IFMTU        => '1500',
                        IFNUMBER     => '46',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '48133765',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan34',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '994741394',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '47',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '159811369',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan35',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '444115092',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '48',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '343716384',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan36',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '26090918',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '49',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '26386466',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan37',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1159731765',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '50',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '635822850',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan38',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1012860431',
                        IFLASTCHANGE => '(9449) 0:01:34.49',
                        IFMTU        => '1500',
                        IFNUMBER     => '51',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1105812410',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan39',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '483221910',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '52',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1086390992',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan40',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1372294888',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '53',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan41',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '53271678',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '54',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan42',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3788610984',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '55',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '788740888',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan43',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '175265926',
                        IFLASTCHANGE => '(12414) 0:02:04.14',
                        IFMTU        => '1500',
                        IFNUMBER     => '56',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '12227212',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan44',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '84632128',
                        IFLASTCHANGE => '(6809) 0:01:08.09',
                        IFMTU        => '1500',
                        IFNUMBER     => '57',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan45',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '13189',
                        IFLASTCHANGE => '(9456) 0:01:34.56',
                        IFMTU        => '1500',
                        IFNUMBER     => '58',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '14842476',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan46',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '629688708',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '59',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '551114293',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan47',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '169895626',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '60',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '12975579',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan48',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '23318539',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '61',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '35099834',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan49',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '3910236074',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '62',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '717502962',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan51',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '2179892942',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '64',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1827466661',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan52',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '758642986',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '65',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1424152021',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan53',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1288949915',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '66',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '849499777',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan54',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '373853733',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '67',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '109925764',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan55',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '51236994',
                        IFLASTCHANGE => '(3092517394) 357 days, 22:19:33.94',
                        IFMTU        => '1500',
                        IFNUMBER     => '68',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '32528595',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan56',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '1483759603',
                        IFLASTCHANGE => '(1823189271) 211 days, 0:24:52.71',
                        IFMTU        => '1500',
                        IFNUMBER     => '69',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '1282294180',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan57',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '204458057',
                        IFLASTCHANGE => '(12415) 0:02:04.15',
                        IFMTU        => '1500',
                        IFNUMBER     => '70',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '164583998',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan99',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '49770978',
                        IFLASTCHANGE => '(9457) 0:01:34.57',
                        IFMTU        => '1500',
                        IFNUMBER     => '74',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '49456490',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan58',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '836890474',
                        IFLASTCHANGE => '(1980745831) 229 days, 6:04:18.31',
                        IFMTU        => '1500',
                        IFNUMBER     => '75',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '40488',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan60',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '108352',
                        IFLASTCHANGE => '(1565251543) 181 days, 3:55:15.43',
                        IFMTU        => '1500',
                        IFNUMBER     => '77',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '0',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan63',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '890715195',
                        IFLASTCHANGE => '(3300554327) 382 days, 0:12:23.27',
                        IFMTU        => '1500',
                        IFNUMBER     => '79',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '354716286',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    },
                    {
                        IFDESCR      => 'Vlan64',
                        IFINERRORS   => '0',
                        IFINOCTETS   => '0',
                        IFLASTCHANGE => '(3791708590) 438 days, 20:31:25.90',
                        IFMTU        => '1500',
                        IFNUMBER     => '80',
                        IFOUTERRORS  => '0',
                        IFOUTOCTETS  => '30300',
                        IFSPEED      => '1000000000',
                        IFTYPE       => 'propVirtual(53)',
                        MAC          => '00:0B:5F:CC:D8:80'
                    }
                ]
            }
        }
    ],
);

setPlan(scalar keys %tests);

my $dictionary = getDictionnary();
my $index      = getIndex();

foreach my $test (sort keys %tests) {
    my $snmp  = getSNMP($test);
    my $model = getModel($index, $tests{$test}->[1]->{MODELSNMP});

    my %device0 = getDeviceInfo($snmp);
    cmp_deeply(\%device0, $tests{$test}->[0], "$test: base stage");

    my %device1 = getDeviceInfo($snmp, $dictionary);
    cmp_deeply(\%device1, $tests{$test}->[1], "$test: base + dictionnary stage");

    my $device3 = getDeviceFullInfo(
        snmp  => $snmp,
        model => $model,
    );
    cmp_deeply($device3, $tests{$test}->[2], "$test: base + model stage");
}
